/* FS1RMain */

#import <Cocoa/Cocoa.h>
#import <CoreMIDI/MidiServices.h>
#import "SelectableImageCell.h"

//---------------------------------------------------------------------------------------------------
// Global Memory
//---------------------------------------------------------------------------------------------------

bool DataSetFlag;
bool FreqCoarseFlag;

Byte MidiInData[1024];
int  MidiInDataCount;

double TimeVal;
NSTimer *timer;

int MIDISettingInValue;
int MIDISettingOutValue;
int MIDISettingKeyValue;

//----------------------------------------------------
// Table
//----------------------------------------------------
char VoiceNameTable[128][13][22];
char FreqTable[128][21][5];
int FseqPrm[90][6];
int OPAttTable[88][8];

//----------------------------------------------------
// Effect
//----------------------------------------------------
typedef struct {
    NSString *EFXName;
    char EffectName[13];
	int NumOfItems;
    NSString *EFXLabel[18];
    char EffectLabel[18][13];
	Byte SysexMSB[18];
    Byte SysexLSB[18];
    int Type[18];
    int InitValue[18];
} TEFXSetup;

TEFXSetup EFXSetup[41][3];

char EFXTableValue[128][59][7];  // EditBox

Byte SysexMin[59];
int BarMax[59];
int BarLargeChange[59];

char ControlDestName1[41][14][13];
char CtrlDestName2[33][13];

int RevWk;    //Pan
int VarWk[2]; //0:SendVar-Rev 1:Pan
int InsWk[4]; //0:InsDryLvl 1:SendIns-Var 2:SendIns-Rev 3:Pan

//----------------------------------------------------
// Exclusive
//----------------------------------------------------
// Performance
Byte PfmData[411]; // Performance: 400Byte + etc
// Voice
Byte VcData[619];  // Voice:       608Byte + etc
// System
Byte SysData[87];  // System:      76Byte  + etc

//----------------------------------------------------
// Standard MIDI File Struct
//----------------------------------------------------
// Header
typedef struct {
    Byte Chank[4];
    Byte StatusByte[4];
    Byte Format[2];
    Byte NumOfTrack[2];
    Byte Time[2];
    Byte TrackChank[4];
    Byte DataLength[4];
} TSMFHead;

// MetaEvent
typedef struct {
    Byte TrkNameHd[4];
	Byte TrkName[15];
	Byte ClockHd[4];
	Byte Clock[4];
	Byte TempoHd[4];
	Byte Tempo[3];
	Byte TyogoHd[4];
	Byte Tyogo[2];
} TSMFMetaEvent;

// SMFTrack
typedef struct {
    TSMFMetaEvent SMFMetaEvent;
    Byte SMFPfmData[414];
    Byte SMFVcData[4][623];
    Byte SMFSysData[90];
    Byte SMFFoot[5];
} TSMFTrack;

// Standard MIDI File
typedef struct {
    TSMFHead  SMFHead;
    TSMFTrack SMFTrack;
} TSMF;

//----------------------------------------------------
// Parameter Struct
//----------------------------------------------------

//-----------------------
// Performance Parameter
//-----------------------

// Performance Common
typedef struct {
    char PfmName[13];
	int  PfmCategory;
    int  PfmCh;
    int  PfmVolume;
    int  PfmPan;
    int  PfmReverbRtn;
    int  PfmVariationRtn;
    int  PfmNoteshift;
} TPfmCom;

// Performance Part
typedef struct {
    int PfmPartBankNum;
    int PfmPartPrgNum;
    int PfmPartRcvCh;
    int PfmPartRcvChMax;
    int PfmPartVolume;
    int PfmPartInsEffectSw;
    int PfmPartDryLevel;
    int PfmPartReverbSend;
    int PfmPartVariationSend;
} TPfmPartPara;

typedef struct {
    int PfmPartFormant;
    int PfmPartFm;
    int PfmPartVNBalance;
} TPfmPartTonePara;

typedef struct {
    int PfmPartLFO1Speed;
    int PfmPartLFO1Pmod;
    int PfmPartLFO1Delay;
} TPfmPartLFO1;

typedef struct {
    int PfmPartFilterSw;
    int PfmPartFilterFreq;
    int PfmPartFilterReso;
    int PfmPartFilterEGDepth;
    int PfmPartLFO2Speed;
    int PfmPartLFO2FltMod;
} TPfmPartFilter;

// Tone
typedef struct {
    TPfmPartTonePara PfmPartTonePara;
    TPfmPartLFO1     PfmPartLFO1;
    TPfmPartFilter   PfmPartFilter;
} TPfmPartTone;

typedef struct {
    int PfmPartEGAtkTime;
    int PfmPartEGDecayTime;
    int PfmPartEGReleaseTime;
} TPfmPartEG;

typedef struct {
    int PfmPartPEGInitLvl;
    int PfmPartPEGAtkTime;
    int PfmPartPEGRelLvl;
    int PfmPartPEGRelTime;
} TPfmPartPEG;

typedef struct {
    int PfmPartDetune;
    int PfmPartNoteShift;
    int PfmPartPBRange;
    int PfmPartPBRangeLo;
    int PfmPartPortaSw;
    int PfmPartPortaMode;
    int PfmPartPortaTime;
} TPfmPartPitch;

typedef struct {
    int PfmPartMonoPoly;
    int PfmPartMonoPriority;
    int PfmPartSustainRcvSw;
    int PfmPartReserveNote;
    int PfmPartReserveNoteMax;
    int PfmPartNoteLimitLow;
    int PfmPartNoteLimitHigh;
    int PfmPartVelLimitLow;
    int PfmPartVelLimitHigh;
    int PfmPartVelSensDepth;
    int PfmPartVelSensOffset;
    int PfmPartExpLimitLo;
    int PfmPartPan;
    int PfmPartPanScale;
    int PfmPartPanMod;
} TPfmPartOther;

typedef struct {
    TPfmPartPara  PfmPartPara;
    TPfmPartTone  PfmPartTone;
    TPfmPartEG    PfmPartEG;
    TPfmPartPEG   PfmPartPEG;
    TPfmPartPitch PfmPartPitch;
    TPfmPartOther PfmPartOther;
} TPfmPart;

// FSEQ
typedef struct {
    int PfmFseqPart;
    int PfmFseqFseqBank;
    int PfmFseqFseqInt;
    int PfmFseqFseqPre;
    int PfmFseqMode;
    int PfmFseqKeyOnTrig;
    int PfmFseqSpeedSelect;
    int PfmFseqSpeedmidi;
    int PfmFseqSpeed;
    int PfmFseqSpeedVel;
    int PfmFseqLevelVel;
    int PfmFseqPitch;
    int PfmFseqLoopMode;
    int PfmFseqStartDelay;
    int PfmFseqStartOffset;
    int PfmFseqLoopStart;
    int PfmFseqLoopEnd;
    int PfmFseqStartOffsetMax;
    int PfmFseqLoopStartMax;
    int PfmFseqLoopEndMax;
} TPfmFSEQ;

// Control
typedef struct {
    Byte CtrlKN[4];
    Byte CtrlMC[4];
    Byte CtrlFC;
    Byte CtrlBC;
    Byte CtrlMW;
    Byte CtrlCAT;
    Byte CtrlPAT;
    Byte CtrlPB;
    int  CtrlDest;
    int  CtrlDepth;
    Byte CtrlPart[4];
} TPfmCtrl;

// System
typedef struct {
    int CtrlAssignKN[4];
    int CtrlAssignMC[4];
    int CtrlAssignFC;
    int CtrlAssignBC;
    int CtrlAssignFrm;
    int CtrlAssignFM;
    int MasterTuning;
    int MasterNoteShift;
    int VeloCurve;
    int DumpInterval;
    int RcvNote;
    int BCCurve;
    int KnobCtrlMode;
    int RcvKnobCtrl;
    int TransKnobCtrl;
    int RcvBankSel;
    int RcvPgmChange;
    int PgmChangeMode;
    int Play[4];
    int PlayVel[4];
    int MemoryAlloc;
} TSystem;

// EfxPart
typedef struct {
    int EfxIndividual;
} TEfxPart;

// Efx
typedef struct {
    int EfxType;
    int EfxPara[18];
} TEfx;

// Equalizer
typedef struct {
    int EfxEQLowShape;
    int EfxEQHighShape;
    int EfxEQ_Freq[3];
    int EfxEQ_Gain[3];
    int EfxEQ_Q[3];
} TEfxEQ;

// Effect
typedef struct {
    TEfxPart EfxPart;
    TEfx     Efx[3];
    TEfxEQ   EfxEQ;
} TEffect;
   
//-----------------------
// Voice Parameter
//-----------------------

// Voice Common
typedef struct {
    char VoiceName[11];
    int VcCategory;
} TVcName;

typedef struct {
    int VcLFO1Waveform;
    int VcLFO1KeySync;
    int VcLFO1Speed;
    int VcLFO1Delay;
    int VcLFO1PModDepth;
    int VcLFO1AModDepth;
    int VcLFO1FreqModDepth;
    int VcLFO1FltModDepth;
} TVcComLFO1;

typedef struct {
    int VcLFO2Waveform;
    int VcLFO2KeySync;
    int VcLFO2Speed;
    int VcLFO2Phase;
    int VcLFO2FltModDepth;
} TVcComLFO2;

typedef struct {
    int VcFilterPartSw;
    int VcFilterInputGain;
    int VcFilterType;
    int VcFilterCutoffFreq;
    int VcFilterResonance;
    int VcFilterFreqScaling;
    int VcFilterFScaleBP;
    int VcFilterResoVelSns;
} TVcComFilter;

typedef struct {
    int VcFilterEGTime1;
    int VcFilterEGTime2;
    int VcFilterEGTime3;
    int VcFilterEGTime4;
    int VcFilterEGLv1;
    int VcFilterEGLv2;
    int VcFilterEGLv3;
    int VcFilterEGLv4;
    int VcFilterEGTimeScaling;
    int VcFilterEGDepth;
    int VcFilterEGAtkTVelSns;
    int VcFilterEGDepthVelSns;
} TVcComFilterEG;

typedef struct {
    int VcPitchEGLv0;
    int VcPitchEGLv1;
    int VcPitchEGLv2;
    int VcPitchEGLv3;
    int VcPitchEGLv4;
    int VcPitchEGTime1;
    int VcPitchEGTime2;
    int VcPitchEGTime3;
    int VcPitchEGTime4;
    int VcPitchEGTimeScaling;
    int VcPitchEGRange;
    int VcPitchEGVelocitySens;
} TVcComPitchEG;

typedef struct {
    int VcFrmt1Operator;
    int VcFrmt1Parameter;
    int VcFrmt1CtlDepth;
    int VcFrmt2Operator;
    int VcFrmt2Parameter;
    int VcFrmt2CtlDepth;
    int VcFrmt3Operator;
    int VcFrmt3Parameter;
    int VcFrmt3CtlDepth;
    int VcFrmt4Operator;
    int VcFrmt4Parameter;
    int VcFrmt4CtlDepth;
    int VcFrmt5Operator;
    int VcFrmt5Parameter;
    int VcFrmt5CtlDepth;
} TVcComFrmt;

typedef struct {
    int VcFm1Operator;
    int VcFm1Parameter;
    int VcFm1CtlDepth;
    int VcFm2Operator;
    int VcFm2Parameter;
    int VcFm2CtlDepth;
    int VcFm3Operator;
    int VcFm3Parameter;
    int VcFm3CtlDepth;
    int VcFm4Operator;
    int VcFm4Parameter;
    int VcFm4CtlDepth;
    int VcFm5Operator;
    int VcFm5Parameter;
    int VcFm5CtlDepth;
} TVcComFm;

// LFO
typedef struct {
    TVcComLFO1 VcComLFO1;
    TVcComLFO2 VcComLFO2;
} TVcComLFO;

// Voice Common
typedef struct {
    TVcComLFO      VcComLFO;
    TVcComFilter   VcComFilter;
    TVcComFilterEG VcComFilterEG;
    TVcComPitchEG  VcComPitchEG;
    TVcComFrmt     VcComFrmt;
    TVcComFm       VcComFm;
} TVcCom;

// Voice General
typedef struct {
    int  VcAlgorithm;
    int  VcFeedback;
    int  VcNoteShift;
} TVcGeneral;

// Voice Operator
typedef struct {
    int VcVOpFseqSw;
    int VcVOpFseqTrk;
    int VcVOpForm;
    int VcVOpFreqMode;
    int VcVOpFreqCoarse;
    int VcVOpFreqCoarseMax;
    int VcVOpFreqFine;
    int VcVOpFreqFineMax;
    int VcVOpFreqScaling;
    int VcVOpTranspose;
    int VcVOpDetune;
    int VcVOpBandWidth;
    int VcVOpResonance;
    int VcVOpSkirt;
    int VcVOpOutputLvl;
    int VcVOpKeySync;
    int VcVOpLSBP;
    int VcVOpLSLeftDepth;
    int VcVOpLSLeftCrv;
    int VcVOpLSRightDepth;
    int VcVOpLSRightCrv;
    int VcVOpOPAtt;
} TVcVOpOsc;

typedef struct {
    int VcUOpFseqSw;
    int VcUOpFreqMode;
    int VcUOpFreqCoarse;
    int VcUOpFreqFine;
    int VcUOpFreqCoarseWk; // Work
    int VcUOpFreqFineWk;   // Work
    int VcUOpFreqScaling;
    int VcUOpTranspose;
    int VcUOpBandWidth;
    int VcUOpResonance;
    int VcUOpSkirt;
    int VcUOpOutputLvl;
    int VcUOpLvlScaling;
} TVcUOpOsc;

typedef struct {
    int VcOpEGHold;
    int VcOpEGTime1;
    int VcOpEGTime2;
    int VcOpEGTime3;
    int VcOpEGTime4;
    int VcOpEGLv1;
    int VcOpEGLv2;
    int VcOpEGLv3;
    int VcOpEGLv4;
    int VcOpEGTimeScaling;
} TVcOpEG;

typedef struct {
    int VcOpFrqEGInitLvl;
    int VcOpFrqEGAtakLvl;
    int VcOpFrqEGAtakTime;
    int VcOpFrqEGDecayTime;
} TVcOpFrqEG;

typedef struct {
    int VcOpSnsAmpVel;
    int VcOpSnsFreqVel;
    int VcOpSnsAmpEGBias;
    int VcOpSnsFreqBias;
    int VcOpSnsWidthBias;
} TVcOpSns;

typedef struct {
    int VcOpAmpMod;
    int VcOpPitchMod;
    int VcOpFreqMod;
} TVcOpMod;

// VOP
typedef struct {
    TVcVOpOsc   VcOpVOpOsc;
    TVcOpEG     VcVOpEG;
    TVcOpFrqEG  VcVOpFrqEG;
    TVcOpSns    VcVOpSns;
    TVcOpMod    VcVOpMod;
} TVcVOp;

// UOP
typedef struct {
    TVcUOpOsc   VcOpUOpOsc;
    TVcOpEG     VcUOpEG;
    TVcOpFrqEG  VcUOpFrqEG;
    TVcOpSns    VcUOpSns;
    TVcOpMod    VcUOpMod;
} TVcUOp;

// OP
typedef struct {
    TVcVOp VcVOp[8];
    TVcUOp VcUOp[8];
} TVcOp;

// Voice ALL
typedef struct {
    TVcName    VcName;
    TVcCom     VcCom;
    TVcGeneral VcGeneral;
    TVcOp      VcOp;
} TVoice;

//--------------------------------------------------------------------------------

TPfmCom  PfmCom;
TPfmPart PfmPart[4];
TPfmFSEQ PfmFSEQ;
TPfmCtrl PfmCtrl[8];
TSystem  System;
TEffect  Effect;
TVoice   Voice[4];

//--------------------------------------------------------------------------------
// FSEQ File Header
//--------------------------------------------------------------------------------
typedef struct {
    Byte Head[6];        // Reserved
    Byte StoreNum;       // Store Number(0x60 + ?)
    Byte Head2[2];       // Reserved
    char FSEQName[8];
    Byte Reserved1[8];   // Reserved
    Byte StartLoopPoint[2];
    Byte EndLoopPoint[2];
    Byte LoopMode;
    Byte StartOffset;    //speed adjust
    Byte SpeedVel;       //Vel Sens for Tempo
    Byte FseqPitch;      //pitch mode (fseq fixed)
    Byte FormNoteAssign;
    Byte FseqLevelVel;   //pitch tuning
    Byte StartDelay;
    Byte FlameDataFmt;
    Byte Reserved2[2];   // Reserved
    Byte EndStep[2];
} TFSEQHead;

// Internal FSEQ
typedef struct {
    int  IntFseqLoopStart;
    int  IntFseqLoopEnd;
    int  IntFseqLoopMode;
    int  IntFseqStartOffset; //speed adjust
    int  IntFseqSpeedVel;    //Vel Sens for Tempo
    int  IntFseqPitch;       //pitch mode (fseq fixed)
    int  IntFseqLevelVel;    //pitch tuning
    int  IntFseqStartDelay;
    int  IntFseqFlame;       // Valid data
}TIntFSEQ;

TIntFSEQ IntFSEQ[6];

// Mute Switch
int PfmPartMute[4];
int VcVOpMuteSw[4][8];
int VcUOpMuteSw[4][8];

//--------------------------------------------------------------------------------
// SaveFile Struct
//--------------------------------------------------------------------------------

// SaveFile Header
typedef struct{
    char FS1RHeader[12];
    int  Version;
} TSaveFileHd;

// SaveFile Data
typedef struct{
    TSaveFileHd fSaveFileHd;
    TPfmCom     fPfmCom;
    TPfmPart    fPfmPart[4];
    TPfmFSEQ    fPfmFSEQ;
    TPfmCtrl    fPfmCtrl[8];
    TSystem     fSystem;
    TEffect     fEffect;
    TVoice      fVoice[4];
} TSaveFile;

//--------------------------------------------------------------------------------
// EGFile Struct
//--------------------------------------------------------------------------------

// EGFile Header
typedef struct{
    char FS1REGHeader[14];
    int  Version;
    int  NumOfData;
} TEGFileHd;

// EGFile Data
 typedef struct{
    char EGName[11];
    int  EGValue[10];
} TEGFileData;

typedef struct{
    TEGFileHd   fEGFileHd;
    TEGFileData fEGFileData[128];
} TEGFile;

TEGFileData EGFileData[128];

//--------------------------------------------------------------------------------
// Copy Buffer
//--------------------------------------------------------------------------------

TPfmPart CopyPfmPart;
TVoice   CopyVoice;
TVcVOp   CopyVcVOp;
TVcUOp   CopyVcUOp;

// Work
int  RcvChWk;
int  RcvChMaxWk;
int  NoteRsvWk;
int  CopyPfmIndex;
int  CopyVcIndex;
int  CopyOpIndex;
bool PasteVcBankOnOffFlag;
bool AlgPanelCancel;

// Undo
TPfmPart UndoPfmPart;
TVoice   UndoVoice;
int UndoPfmIndex;
int UndoVcIndex;

//--------------------------------------------------------------------------------
// Other
//--------------------------------------------------------------------------------

int  FS1RDevId;
int  StoreNumber;
int  StoreType;
int  FSEQMemoryAlloc;
int  OpTabIndexWk[4];
int  MidiInSysexID;
bool MidiOpenFlag;
bool MidiThruOpenFlag;
bool MidiConnectFlag;
bool BulkDumpFlag;
bool SaveCancel;
bool FirstExec;
int  FSEQStoreNum;
int  FSEQFlameDataFmt;

bool UpdateFlag; //Update Flag
bool FirstBootFlag; // Boot OK Flag

MIDIPortRef MIDIInPort = NULL;
MIDIPortRef MIDIKeyboardPort = NULL;
MIDIPortRef MIDIOutPort = NULL;
MIDIClientRef MIDIClient = NULL;
MIDIEndpointRef MIDIInputEndPoint = NULL;
MIDIEndpointRef MIDIOutputEndPoint = NULL;
MIDIEndpointRef MIDIKeyboardEndPoint = NULL;
int MIDIGlobalCh = 0;

//--------------------------------------------------------------------------------
@interface FS1RMain : NSObject
{
    // Main Window
    IBOutlet id FS1RMainWindow;

    // Tabs
    IBOutlet id Mode_Tab;
    IBOutlet id Pfm_Tab;
	
	// Main Menu
    IBOutlet id MainMenu;

    // About Window
    IBOutlet id AboutPanel;

	// MIDI Data Send & Receive Progress Panel
	IBOutlet id ProgressPanel;
	IBOutlet id ProgressPanel_LeftImage;
	IBOutlet id ProgressPanel_RightImage;
	IBOutlet id ProgressPanel_Anim;
	IBOutlet id ProgressPanel_Bar;
    
	// Store Panel
	IBOutlet id StorePanel;
	IBOutlet id StorePanel_Text;
	IBOutlet id StorePanel_Bar;
	IBOutlet id StorePanel_Edit;
	IBOutlet id StorePanel_Store;
	IBOutlet id StorePanel_Cancel;

	// FSEQ Init Panel
	IBOutlet id FSEQInitPanel;
	IBOutlet id FSEQInitPanel_OK;

	// VirtualMIDIKeyboadPanel
	IBOutlet id VMIDIKeyPanel;
	IBOutlet id VMIDIKeyPanel_B0;
	IBOutlet id VMIDIKeyPanel_C1;
	IBOutlet id VMIDIKeyPanel_C1s;
	IBOutlet id VMIDIKeyPanel_D1;
	IBOutlet id VMIDIKeyPanel_D1s;
	IBOutlet id VMIDIKeyPanel_E1;
	IBOutlet id VMIDIKeyPanel_F1;
	IBOutlet id VMIDIKeyPanel_F1s;
	IBOutlet id VMIDIKeyPanel_G1;
	IBOutlet id VMIDIKeyPanel_G1s;
	IBOutlet id VMIDIKeyPanel_A1;
	IBOutlet id VMIDIKeyPanel_A1s;
	IBOutlet id VMIDIKeyPanel_B1;
	IBOutlet id VMIDIKeyPanel_C2;
	IBOutlet id VMIDIKeyPanel_C2s;
	IBOutlet id VMIDIKeyPanel_D2;
	IBOutlet id VMIDIKeyPanel_D2s;
	IBOutlet id VMIDIKeyPanel_E2;
	IBOutlet id VMIDIKeyPanel_F2;
	IBOutlet id VMIDIKeyPanel_F2s;
	IBOutlet id VMIDIKeyPanel_G2;
	IBOutlet id VMIDIKeyPanel_G2s;
	IBOutlet id VMIDIKeyPanel_A2;
	IBOutlet id VMIDIKeyPanel_A2s;
	IBOutlet id VMIDIKeyPanel_B2;
	IBOutlet id VMIDIKeyPanel_C3;
	IBOutlet id VMIDIKeyPanel_C3s;
	IBOutlet id VMIDIKeyPanel_D3;
	IBOutlet id VMIDIKeyPanel_D3s;
	IBOutlet id VMIDIKeyPanel_E3;
	IBOutlet id VMIDIKeyPanel_F3;
	IBOutlet id VMIDIKeyPanel_F3s;
	IBOutlet id VMIDIKeyPanel_G3;
	IBOutlet id VMIDIKeyPanel_G3s;
	IBOutlet id VMIDIKeyPanel_A3;
	IBOutlet id VMIDIKeyPanel_A3s;
	IBOutlet id VMIDIKeyPanel_B3;
	IBOutlet id VMIDIKeyPanel_C4;
	IBOutlet id VMIDIKeyPanel_C4s;
	IBOutlet id VMIDIKeyPanel_D4;
	IBOutlet id VMIDIKeyPanel_D4s;
	IBOutlet id VMIDIKeyPanel_E4;
	IBOutlet id VMIDIKeyPanel_F4;
	IBOutlet id VMIDIKeyPanel_F4s;
	IBOutlet id VMIDIKeyPanel_G4;
	IBOutlet id VMIDIKeyPanel_G4s;
	IBOutlet id VMIDIKeyPanel_A4;
	IBOutlet id VMIDIKeyPanel_A4s;
	IBOutlet id VMIDIKeyPanel_B4;
	IBOutlet id VMIDIKeyPanel_C5;
	IBOutlet id VMIDIKeyPanel_C5s;
	IBOutlet id VMIDIKeyPanel_D5;
	IBOutlet id VMIDIKeyPanel_D5s;
	IBOutlet id VMIDIKeyPanel_E5;
	IBOutlet id VMIDIKeyPanel_F5;
	IBOutlet id VMIDIKeyPanel_F5s;
	IBOutlet id VMIDIKeyPanel_G5;
	IBOutlet id VMIDIKeyPanel_G5s;
	IBOutlet id VMIDIKeyPanel_A5;
	IBOutlet id VMIDIKeyPanel_A5s;
	IBOutlet id VMIDIKeyPanel_B5;

	IBOutlet id VMIDIKeyPanel_Ch;
	IBOutlet id VMIDIKeyPanel_OctShift;
	IBOutlet id VMIDIKeyPanel_VelocityBar;
	IBOutlet id VMIDIKeyPanel_VelocityEdit;
	IBOutlet id VMIDIKeyPanel_Ctrl1;
	IBOutlet id VMIDIKeyPanel_Ctrl1Bar;
	IBOutlet id VMIDIKeyPanel_Ctrl1Edit;
	IBOutlet id VMIDIKeyPanel_Ctrl2;
	IBOutlet id VMIDIKeyPanel_Ctrl2Bar;
	IBOutlet id VMIDIKeyPanel_Ctrl2Edit;
	IBOutlet id VMIDIKeyPanel_KeyRetrigger;
	IBOutlet id VMIDIKeyPanel_AllReset;

	// Alg Select Panel
	IBOutlet id AlgSelectPanel;
	IBOutlet id AlgSelectPanel_AlgEdit;
	IBOutlet id AlgSelectPanel_Matrix;

    // MIDI Setting Panel
    IBOutlet id MIDIIntPanel;
    IBOutlet id MIDISetting_InputPort;
    IBOutlet id MIDISetting_OutputPort;
    IBOutlet id MIDISetting_KeyboardPort;
    IBOutlet id MIDISetting_DevID;

    // Main Menu
    // File
	IBOutlet id FileNewItem;
	IBOutlet id FileOpenItem;
	IBOutlet id FileSaveItem;
	IBOutlet id ExportSMF;
    // Edit
	IBOutlet id Undo;
	IBOutlet id Copy;
	IBOutlet id Paste;
	IBOutlet id OPCopy;
	IBOutlet id OPPaste;
	// tools
	IBOutlet id DataSendPfm;
	IBOutlet id DataSendVc1;
	IBOutlet id DataSendVc2;
	IBOutlet id DataSendVc3;
	IBOutlet id DataSendVc4;
	IBOutlet id DataSendSys;
	IBOutlet id DataSendAll;
	IBOutlet id DataRcvPfm;
	IBOutlet id DataRcvVc1;
	IBOutlet id DataRcvVc2;
	IBOutlet id DataRcvVc3;
	IBOutlet id DataRcvVc4;
	IBOutlet id DataRcvSys;
	IBOutlet id DataRcvAll;
	IBOutlet id StorePfm;
	IBOutlet id StoreVc1;
	IBOutlet id StoreVc2;
	IBOutlet id StoreVc3;
	IBOutlet id StoreVc4;
	IBOutlet id InitPfm;
	IBOutlet id InitVc1;
	IBOutlet id InitVc2;
	IBOutlet id InitVc3;
	IBOutlet id InitVc4;
	IBOutlet id InitAll;
	// Options
	IBOutlet id MIDI_config;	
	IBOutlet id VirtualKey;
	IBOutlet id PanicCancel;
	
    // Objects of Main Window
	IBOutlet id Pfm_Name;
	IBOutlet id Pfm_Category;
	IBOutlet id Pfm_Ch;
	IBOutlet id Pfm_PartMuteBtn1;
	IBOutlet id Pfm_PartMuteBtn2;
	IBOutlet id Pfm_PartMuteBtn3;
	IBOutlet id Pfm_PartMuteBtn4;
	IBOutlet id Pfm_VolumeBar;
	IBOutlet id Pfm_VolumeEdit;
	IBOutlet id Pfm_PanBar;
	IBOutlet id Pfm_Pan;
	IBOutlet id Pfm_ReverbRtnBar;
	IBOutlet id Pfm_ReverbRtnEdit;
	IBOutlet id Pfm_VariationRtnBar;
	IBOutlet id Pfm_VariationRtnEdit;
	IBOutlet id Pfm_NoteshiftBar;
	IBOutlet id Pfm_NoteshiftEdit;
	IBOutlet id Pfm_ReceiveBtn;
	IBOutlet id Pfm_TransmitBtn;
	
	// Object of Part Parameters
	IBOutlet id Pfm_Part_SelectMatrix;

    IBOutlet id Pfm_Part_BankNum;
    IBOutlet id Pfm_Part_PrgNum;
    IBOutlet id Pfm_Part_RcvCh;
    IBOutlet id Pfm_Part_RcvChMaxText;
    IBOutlet id Pfm_Part_RcvChMax;
	IBOutlet id Pfm_Part_VolumeText;
    IBOutlet id Pfm_Part_VolumeBar;
    IBOutlet id Pfm_Part_VolumeEdit;
    IBOutlet id Pfm_Part_InsEffectSw;
    IBOutlet id Pfm_Part_DryLevelText;
    IBOutlet id Pfm_Part_DryLevelBar;
    IBOutlet id Pfm_Part_DryLevelEdit;
    IBOutlet id Pfm_Part_ReverbSendText;
    IBOutlet id Pfm_Part_ReverbSendBar;
    IBOutlet id Pfm_Part_ReverbSendEdit;
    IBOutlet id Pfm_Part_VariationSendText;
    IBOutlet id Pfm_Part_VariationSendBar;
    IBOutlet id Pfm_Part_VariationSendEdit;

    IBOutlet id Pfm_Part_FormantBar;
    IBOutlet id Pfm_Part_FormantEdit;
    IBOutlet id Pfm_Part_FmBar;
    IBOutlet id Pfm_Part_FmEdit;
    IBOutlet id Pfm_Part_VNBalanceBar;
    IBOutlet id Pfm_Part_VNBalanceEdit;
    IBOutlet id Pfm_Part_LFO1SpeedBar;
    IBOutlet id Pfm_Part_LFO1SpeedEdit;
    IBOutlet id Pfm_Part_LFO1PmodBar;
    IBOutlet id Pfm_Part_LFO1PmodEdit;
    IBOutlet id Pfm_Part_LFO1DelayBar;
    IBOutlet id Pfm_Part_LFO1DelayEdit;
    IBOutlet id Pfm_Part_FilterSw;
    IBOutlet id Pfm_Part_FilterFreqText;
    IBOutlet id Pfm_Part_FilterFreqBar;
    IBOutlet id Pfm_Part_FilterFreqEdit;
    IBOutlet id Pfm_Part_FilterResoText;
    IBOutlet id Pfm_Part_FilterResoBar;
    IBOutlet id Pfm_Part_FilterResoEdit;
    IBOutlet id Pfm_Part_FilterEGDepthText;
    IBOutlet id Pfm_Part_FilterEGDepthBar;
    IBOutlet id Pfm_Part_FilterEGDepthEdit;
    IBOutlet id Pfm_Part_LFO2SpeedText;
    IBOutlet id Pfm_Part_LFO2SpeedBar;
    IBOutlet id Pfm_Part_LFO2SpeedEdit;
    IBOutlet id Pfm_Part_LFO2FltModText;
    IBOutlet id Pfm_Part_LFO2FltModBar;
    IBOutlet id Pfm_Part_LFO2FltModEdit;

    IBOutlet id Pfm_Part_EGAtkTimeBar;
    IBOutlet id Pfm_Part_EGAtkTimeEdit;
    IBOutlet id Pfm_Part_EGDecayTimeBar;
    IBOutlet id Pfm_Part_EGDecayTimeEdit;
    IBOutlet id Pfm_Part_EGReleaseTimeBar;
    IBOutlet id Pfm_Part_EGReleaseTimeEdit;

    IBOutlet id Pfm_Part_PEGInitLvlBar;
    IBOutlet id Pfm_Part_PEGInitLvlEdit;
    IBOutlet id Pfm_Part_PEGAtkTimeBar;
    IBOutlet id Pfm_Part_PEGAtkTimeEdit;
    IBOutlet id Pfm_Part_PEGRelLvlBar;
    IBOutlet id Pfm_Part_PEGRelLvlEdit;
    IBOutlet id Pfm_Part_PEGRelTimeBar;
    IBOutlet id Pfm_Part_PEGRelTimeEdit;

    IBOutlet id Pfm_Part_DetuneBar;
    IBOutlet id Pfm_Part_DetuneEdit;
    IBOutlet id Pfm_Part_NoteShiftBar;
    IBOutlet id Pfm_Part_NoteShiftEdit;
    IBOutlet id Pfm_Part_PBRangeBar;
    IBOutlet id Pfm_Part_PBRangeEdit;
    IBOutlet id Pfm_Part_PBRangeLoBar;
    IBOutlet id Pfm_Part_PBRangeLoEdit;
    IBOutlet id Pfm_Part_PortaSw;
    IBOutlet id Pfm_Part_PortaModeText;
    IBOutlet id Pfm_Part_PortaMode;
    IBOutlet id Pfm_Part_PortaTimeText;
    IBOutlet id Pfm_Part_PortaTimeBar;
    IBOutlet id Pfm_Part_PortaTimeEdit;

    IBOutlet id Pfm_Part_SustainRcvSw;
    IBOutlet id Pfm_Part_MonoPoly;
    IBOutlet id Pfm_Part_MonoPriorityText;
    IBOutlet id Pfm_Part_MonoPriority;
    IBOutlet id Pfm_Part_ReserveNoteBar;
    IBOutlet id Pfm_Part_ReserveNoteEdit;
    IBOutlet id Pfm_Part_NoteLimitLow;
    IBOutlet id Pfm_Part_NoteLimitHigh;
    IBOutlet id Pfm_Part_VelLimitLowBar;
    IBOutlet id Pfm_Part_VelLimitLowEdit;
    IBOutlet id Pfm_Part_VelLimitHighBar;
    IBOutlet id Pfm_Part_VelLimitHighEdit;
    IBOutlet id Pfm_Part_VelSensDepthBar;
    IBOutlet id Pfm_Part_VelSensDepthEdit;
    IBOutlet id Pfm_Part_VelSensOffsetBar;
    IBOutlet id Pfm_Part_VelSensOffsetEdit;
    IBOutlet id Pfm_Part_ExpLimitLoBar;
    IBOutlet id Pfm_Part_ExpLimitLoEdit;
    IBOutlet id Pfm_Part_PanBar;
    IBOutlet id Pfm_Part_Pan;
    IBOutlet id Pfm_Part_PanScaleBar;
    IBOutlet id Pfm_Part_PanScaleEdit;
    IBOutlet id Pfm_Part_PanModBar;
    IBOutlet id Pfm_Part_PanModEdit;
	
	// FSEQ Objects
    IBOutlet id Pfm_Fseq_Part;
    IBOutlet id Pfm_Fseq_FseqBank;
    IBOutlet id Pfm_Fseq_FseqInt;
    IBOutlet id Pfm_Fseq_FseqIntWrite;
    IBOutlet id Pfm_Fseq_FseqTestBtn;
    IBOutlet id Pfm_Fseq_FseqIntClear;
    IBOutlet id Pfm_Fseq_FseqPre;
    IBOutlet id Pfm_Fseq_Mode;
    IBOutlet id Pfm_Fseq_KeyOnTrigText;
    IBOutlet id Pfm_Fseq_KeyOnTrig;
    IBOutlet id Pfm_Fseq_SpeedSelect;
    IBOutlet id Pfm_Fseq_Speedmidi;
    IBOutlet id Pfm_Fseq_SpeedText;
	IBOutlet id Pfm_Fseq_SpeedUpBtn;
	IBOutlet id Pfm_Fseq_SpeedUpBtn2;
	IBOutlet id Pfm_Fseq_SpeedBar;
	IBOutlet id Pfm_Fseq_SpeedDownBtn;
	IBOutlet id Pfm_Fseq_SpeedDownBtn2;
    IBOutlet id Pfm_Fseq_SpeedEdit;
    IBOutlet id Pfm_Fseq_SpeedPercentText;
    IBOutlet id Pfm_Fseq_SpeedVelText;
    IBOutlet id Pfm_Fseq_SpeedVelBar;
    IBOutlet id Pfm_Fseq_SpeedVelEdit;
    IBOutlet id Pfm_Fseq_LevelVelBar;
    IBOutlet id Pfm_Fseq_LevelVelEdit;
    IBOutlet id Pfm_Fseq_Pitch;
    IBOutlet id Pfm_Fseq_LoopModeText;
    IBOutlet id Pfm_Fseq_LoopMode;
	IBOutlet id Pfm_Fseq_StartDelayText;
    IBOutlet id Pfm_Fseq_StartDelayBar;
    IBOutlet id Pfm_Fseq_StartDelayEdit;
    IBOutlet id Pfm_Fseq_StartOffsetDownBtn;
    IBOutlet id Pfm_Fseq_StartOffsetBar;
    IBOutlet id Pfm_Fseq_StartOffsetEdit;
    IBOutlet id Pfm_Fseq_StartOffsetUpBtn;
    IBOutlet id Pfm_Fseq_LoopStartText;
    IBOutlet id Pfm_Fseq_LoopStartDownBtn;
    IBOutlet id Pfm_Fseq_LoopStartBar;
    IBOutlet id Pfm_Fseq_LoopStartEdit;
    IBOutlet id Pfm_Fseq_LoopStartUpBtn;
    IBOutlet id Pfm_Fseq_LoopEndText;
    IBOutlet id Pfm_Fseq_LoopEndDownBtn;
    IBOutlet id Pfm_Fseq_LoopEndBar;
    IBOutlet id Pfm_Fseq_LoopEndEdit;
    IBOutlet id Pfm_Fseq_LoopEndUpBtn;

    // System Parameters
    IBOutlet id Pfm_SystemMstrTuneBar;
    IBOutlet id Pfm_SystemMstrTuneEdit;
    IBOutlet id Pfm_SystemMstrNoteBar;
    IBOutlet id Pfm_SystemMstrNoteEdit;
    IBOutlet id Pfm_SystemVelCrv;
    IBOutlet id Pfm_SystemDumpInterval;
    IBOutlet id Pfm_SystemRcvNote;
    IBOutlet id Pfm_SystemBCCurve;
    IBOutlet id Pfm_SystemKNCtrlMode;
    IBOutlet id Pfm_SystemRcvKNCtrl;
    IBOutlet id Pfm_SystemTrnKNCtrl;
    IBOutlet id Pfm_SystemRcvBankSelectText;
    IBOutlet id Pfm_SystemRcvBankSelect;
    IBOutlet id Pfm_SystemRcvPgmChange;
    IBOutlet id Pfm_SystemRcvPgmMode;
    IBOutlet id Pfm_SystemDataRcvBtn;
	IBOutlet id Pfm_SystemDataSendBtn;

	// Control Section
	IBOutlet id Pfm_Ctrl_Chk1_KN1;
	IBOutlet id Pfm_Ctrl_Chk1_KN2;
	IBOutlet id Pfm_Ctrl_Chk1_KN3;
	IBOutlet id Pfm_Ctrl_Chk1_KN4;
	IBOutlet id Pfm_Ctrl_Chk1_MC1;
	IBOutlet id Pfm_Ctrl_Chk1_MC2;
	IBOutlet id Pfm_Ctrl_Chk1_MC3;
	IBOutlet id Pfm_Ctrl_Chk1_MC4;
	IBOutlet id Pfm_Ctrl_Chk1_FC;
	IBOutlet id Pfm_Ctrl_Chk1_BC;
	IBOutlet id Pfm_Ctrl_Chk1_MW;
	IBOutlet id Pfm_Ctrl_Chk1_CAT;
	IBOutlet id Pfm_Ctrl_Chk1_PAT;
	IBOutlet id Pfm_Ctrl_Chk1_PB;
	IBOutlet id Pfm_Ctrl_Dest1;
	IBOutlet id Pfm_Ctrl_Depth1Bar;
	IBOutlet id Pfm_Ctrl_Depth1Edit;
	IBOutlet id Pfm_Ctrl_Chk1_P1;
	IBOutlet id Pfm_Ctrl_Chk1_P2;
	IBOutlet id Pfm_Ctrl_Chk1_P3;
	IBOutlet id Pfm_Ctrl_Chk1_P4;

	IBOutlet id Pfm_Ctrl_Chk2_KN1;
	IBOutlet id Pfm_Ctrl_Chk2_KN2;
	IBOutlet id Pfm_Ctrl_Chk2_KN3;
	IBOutlet id Pfm_Ctrl_Chk2_KN4;
	IBOutlet id Pfm_Ctrl_Chk2_MC1;
	IBOutlet id Pfm_Ctrl_Chk2_MC2;
	IBOutlet id Pfm_Ctrl_Chk2_MC3;
	IBOutlet id Pfm_Ctrl_Chk2_MC4;
	IBOutlet id Pfm_Ctrl_Chk2_FC;
	IBOutlet id Pfm_Ctrl_Chk2_BC;
	IBOutlet id Pfm_Ctrl_Chk2_MW;
	IBOutlet id Pfm_Ctrl_Chk2_CAT;
	IBOutlet id Pfm_Ctrl_Chk2_PAT;
	IBOutlet id Pfm_Ctrl_Chk2_PB;
	IBOutlet id Pfm_Ctrl_Dest2;
	IBOutlet id Pfm_Ctrl_Depth2Bar;
	IBOutlet id Pfm_Ctrl_Depth2Edit;
	IBOutlet id Pfm_Ctrl_Chk2_P1;
	IBOutlet id Pfm_Ctrl_Chk2_P2;
	IBOutlet id Pfm_Ctrl_Chk2_P3;
	IBOutlet id Pfm_Ctrl_Chk2_P4;

	IBOutlet id Pfm_Ctrl_Chk3_KN1;
	IBOutlet id Pfm_Ctrl_Chk3_KN2;
	IBOutlet id Pfm_Ctrl_Chk3_KN3;
	IBOutlet id Pfm_Ctrl_Chk3_KN4;
	IBOutlet id Pfm_Ctrl_Chk3_MC1;
	IBOutlet id Pfm_Ctrl_Chk3_MC2;
	IBOutlet id Pfm_Ctrl_Chk3_MC3;
	IBOutlet id Pfm_Ctrl_Chk3_MC4;
	IBOutlet id Pfm_Ctrl_Chk3_FC;
	IBOutlet id Pfm_Ctrl_Chk3_BC;
	IBOutlet id Pfm_Ctrl_Chk3_MW;
	IBOutlet id Pfm_Ctrl_Chk3_CAT;
	IBOutlet id Pfm_Ctrl_Chk3_PAT;
	IBOutlet id Pfm_Ctrl_Chk3_PB;
	IBOutlet id Pfm_Ctrl_Dest3;
	IBOutlet id Pfm_Ctrl_Depth3Bar;
	IBOutlet id Pfm_Ctrl_Depth3Edit;
	IBOutlet id Pfm_Ctrl_Chk3_P1;
	IBOutlet id Pfm_Ctrl_Chk3_P2;
	IBOutlet id Pfm_Ctrl_Chk3_P3;
	IBOutlet id Pfm_Ctrl_Chk3_P4;

	IBOutlet id Pfm_Ctrl_Chk4_KN1;
	IBOutlet id Pfm_Ctrl_Chk4_KN2;
	IBOutlet id Pfm_Ctrl_Chk4_KN3;
	IBOutlet id Pfm_Ctrl_Chk4_KN4;
	IBOutlet id Pfm_Ctrl_Chk4_MC1;
	IBOutlet id Pfm_Ctrl_Chk4_MC2;
	IBOutlet id Pfm_Ctrl_Chk4_MC3;
	IBOutlet id Pfm_Ctrl_Chk4_MC4;
	IBOutlet id Pfm_Ctrl_Chk4_FC;
	IBOutlet id Pfm_Ctrl_Chk4_BC;
	IBOutlet id Pfm_Ctrl_Chk4_MW;
	IBOutlet id Pfm_Ctrl_Chk4_CAT;
	IBOutlet id Pfm_Ctrl_Chk4_PAT;
	IBOutlet id Pfm_Ctrl_Chk4_PB;
	IBOutlet id Pfm_Ctrl_Dest4;
	IBOutlet id Pfm_Ctrl_Depth4Bar;
	IBOutlet id Pfm_Ctrl_Depth4Edit;
	IBOutlet id Pfm_Ctrl_Chk4_P1;
	IBOutlet id Pfm_Ctrl_Chk4_P2;
	IBOutlet id Pfm_Ctrl_Chk4_P3;
	IBOutlet id Pfm_Ctrl_Chk4_P4;

	IBOutlet id Pfm_Ctrl_Chk5_KN1;
	IBOutlet id Pfm_Ctrl_Chk5_KN2;
	IBOutlet id Pfm_Ctrl_Chk5_KN3;
	IBOutlet id Pfm_Ctrl_Chk5_KN4;
	IBOutlet id Pfm_Ctrl_Chk5_MC1;
	IBOutlet id Pfm_Ctrl_Chk5_MC2;
	IBOutlet id Pfm_Ctrl_Chk5_MC3;
	IBOutlet id Pfm_Ctrl_Chk5_MC4;
	IBOutlet id Pfm_Ctrl_Chk5_FC;
	IBOutlet id Pfm_Ctrl_Chk5_BC;
	IBOutlet id Pfm_Ctrl_Chk5_MW;
	IBOutlet id Pfm_Ctrl_Chk5_CAT;
	IBOutlet id Pfm_Ctrl_Chk5_PAT;
	IBOutlet id Pfm_Ctrl_Chk5_PB;
	IBOutlet id Pfm_Ctrl_Dest5;
	IBOutlet id Pfm_Ctrl_Depth5Bar;
	IBOutlet id Pfm_Ctrl_Depth5Edit;
	IBOutlet id Pfm_Ctrl_Chk5_P1;
	IBOutlet id Pfm_Ctrl_Chk5_P2;
	IBOutlet id Pfm_Ctrl_Chk5_P3;
	IBOutlet id Pfm_Ctrl_Chk5_P4;

	IBOutlet id Pfm_Ctrl_Chk6_KN1;
	IBOutlet id Pfm_Ctrl_Chk6_KN2;
	IBOutlet id Pfm_Ctrl_Chk6_KN3;
	IBOutlet id Pfm_Ctrl_Chk6_KN4;
	IBOutlet id Pfm_Ctrl_Chk6_MC1;
	IBOutlet id Pfm_Ctrl_Chk6_MC2;
	IBOutlet id Pfm_Ctrl_Chk6_MC3;
	IBOutlet id Pfm_Ctrl_Chk6_MC4;
	IBOutlet id Pfm_Ctrl_Chk6_FC;
	IBOutlet id Pfm_Ctrl_Chk6_BC;
	IBOutlet id Pfm_Ctrl_Chk6_MW;
	IBOutlet id Pfm_Ctrl_Chk6_CAT;
	IBOutlet id Pfm_Ctrl_Chk6_PAT;
	IBOutlet id Pfm_Ctrl_Chk6_PB;
	IBOutlet id Pfm_Ctrl_Dest6;
	IBOutlet id Pfm_Ctrl_Depth6Bar;
	IBOutlet id Pfm_Ctrl_Depth6Edit;
	IBOutlet id Pfm_Ctrl_Chk6_P1;
	IBOutlet id Pfm_Ctrl_Chk6_P2;
	IBOutlet id Pfm_Ctrl_Chk6_P3;
	IBOutlet id Pfm_Ctrl_Chk6_P4;

	IBOutlet id Pfm_Ctrl_Chk7_KN1;
	IBOutlet id Pfm_Ctrl_Chk7_KN2;
	IBOutlet id Pfm_Ctrl_Chk7_KN3;
	IBOutlet id Pfm_Ctrl_Chk7_KN4;
	IBOutlet id Pfm_Ctrl_Chk7_MC1;
	IBOutlet id Pfm_Ctrl_Chk7_MC2;
	IBOutlet id Pfm_Ctrl_Chk7_MC3;
	IBOutlet id Pfm_Ctrl_Chk7_MC4;
	IBOutlet id Pfm_Ctrl_Chk7_FC;
	IBOutlet id Pfm_Ctrl_Chk7_BC;
	IBOutlet id Pfm_Ctrl_Chk7_MW;
	IBOutlet id Pfm_Ctrl_Chk7_CAT;
	IBOutlet id Pfm_Ctrl_Chk7_PAT;
	IBOutlet id Pfm_Ctrl_Chk7_PB;
	IBOutlet id Pfm_Ctrl_Dest7;
	IBOutlet id Pfm_Ctrl_Depth7Bar;
	IBOutlet id Pfm_Ctrl_Depth7Edit;
	IBOutlet id Pfm_Ctrl_Chk7_P1;
	IBOutlet id Pfm_Ctrl_Chk7_P2;
	IBOutlet id Pfm_Ctrl_Chk7_P3;
	IBOutlet id Pfm_Ctrl_Chk7_P4;

	IBOutlet id Pfm_Ctrl_Chk8_KN1;
	IBOutlet id Pfm_Ctrl_Chk8_KN2;
	IBOutlet id Pfm_Ctrl_Chk8_KN3;
	IBOutlet id Pfm_Ctrl_Chk8_KN4;
	IBOutlet id Pfm_Ctrl_Chk8_MC1;
	IBOutlet id Pfm_Ctrl_Chk8_MC2;
	IBOutlet id Pfm_Ctrl_Chk8_MC3;
	IBOutlet id Pfm_Ctrl_Chk8_MC4;
	IBOutlet id Pfm_Ctrl_Chk8_FC;
	IBOutlet id Pfm_Ctrl_Chk8_BC;
	IBOutlet id Pfm_Ctrl_Chk8_MW;
	IBOutlet id Pfm_Ctrl_Chk8_CAT;
	IBOutlet id Pfm_Ctrl_Chk8_PAT;
	IBOutlet id Pfm_Ctrl_Chk8_PB;
	IBOutlet id Pfm_Ctrl_Dest8;
	IBOutlet id Pfm_Ctrl_Depth8Bar;
	IBOutlet id Pfm_Ctrl_Depth8Edit;
	IBOutlet id Pfm_Ctrl_Chk8_P1;
	IBOutlet id Pfm_Ctrl_Chk8_P2;
	IBOutlet id Pfm_Ctrl_Chk8_P3;
	IBOutlet id Pfm_Ctrl_Chk8_P4;

	IBOutlet id Pfm_Ctrl_AssignKN1;
	IBOutlet id Pfm_Ctrl_AssignKN2;
	IBOutlet id Pfm_Ctrl_AssignKN3;
	IBOutlet id Pfm_Ctrl_AssignKN4;
	IBOutlet id Pfm_Ctrl_AssignMC1;
	IBOutlet id Pfm_Ctrl_AssignMC2;
	IBOutlet id Pfm_Ctrl_AssignMC3;
	IBOutlet id Pfm_Ctrl_AssignMC4;
	IBOutlet id Pfm_Ctrl_AssignFC;
	IBOutlet id Pfm_Ctrl_AssignBC;
	IBOutlet id Pfm_Ctrl_AssignFrm;
	IBOutlet id Pfm_Ctrl_AssignFM;
	IBOutlet id Pfm_Ctrl_AssignDefaultBtn;

	//  Voice Parameters
	IBOutlet id Vc_Voice;
	IBOutlet id Vc_Name;
	IBOutlet id Vc_Category;

	IBOutlet id Vc_LFO1Waveform;
	IBOutlet id Vc_LFO1KeySync;
	IBOutlet id Vc_LFO1SpeedBar;
	IBOutlet id Vc_LFO1SpeedEdit;
	IBOutlet id Vc_LFO1DelayBar;
	IBOutlet id Vc_LFO1DelayEdit;
	IBOutlet id Vc_LFO1PModDepthBar;
	IBOutlet id Vc_LFO1PModDepthEdit;
	IBOutlet id Vc_LFO1AModDepthBar;
	IBOutlet id Vc_LFO1AModDepthEdit;
	IBOutlet id Vc_LFO1FreqModDepthBar;
	IBOutlet id Vc_LFO1FreqModDepthEdit;
	IBOutlet id Vc_LFO1FltModDepthBar;
	IBOutlet id Vc_LFO1FltModDepthEdit;
	IBOutlet id Vc_LFO2Waveform;
	IBOutlet id Vc_LFO2KeySync;
	IBOutlet id Vc_LFO2SpeedBar;
	IBOutlet id Vc_LFO2SpeedEdit;
	IBOutlet id Vc_LFO2Phase;
	IBOutlet id Vc_LFO2FltModDepthBar;
	IBOutlet id Vc_LFO2FltModDepthEdit;

	IBOutlet id Vc_FilterPartSw;
	IBOutlet id Vc_FilterInputGainBar;
	IBOutlet id Vc_FilterInputGainEdit;
	IBOutlet id Vc_FilterType;
	IBOutlet id Vc_FilterCutoffFreqBar;
	IBOutlet id Vc_FilterCutoffFreqEdit;
	IBOutlet id Vc_FilterResonanceBar;
	IBOutlet id Vc_FilterResonanceEdit;
	IBOutlet id Vc_FilterFreqScalingBar;
	IBOutlet id Vc_FilterFreqScalingEdit;
	IBOutlet id Vc_FilterFScaleBP;
	IBOutlet id Vc_FilterResoVelSnsBar;
	IBOutlet id Vc_FilterResoVelSnsEdit;

	IBOutlet id Vc_FilterGraphView;
	IBOutlet id Vc_FilterEGTime1Bar;
	IBOutlet id Vc_FilterEGTime1Edit;
	IBOutlet id Vc_FilterEGTime2Bar;
	IBOutlet id Vc_FilterEGTime2Edit;
	IBOutlet id Vc_FilterEGTime3Bar;
	IBOutlet id Vc_FilterEGTime3Edit;
	IBOutlet id Vc_FilterEGTime4Bar;
	IBOutlet id Vc_FilterEGTime4Edit;
	IBOutlet id Vc_FilterEGLv1Bar;
	IBOutlet id Vc_FilterEGLv1Edit;
	IBOutlet id Vc_FilterEGLv2Bar;
	IBOutlet id Vc_FilterEGLv2Edit;
	IBOutlet id Vc_FilterEGLv3Bar;
	IBOutlet id Vc_FilterEGLv3Edit;
	IBOutlet id Vc_FilterEGLv4Bar;
	IBOutlet id Vc_FilterEGLv4Edit;
	IBOutlet id Vc_FilterEGTimeScalingBar;
	IBOutlet id Vc_FilterEGTimeScalingEdit;
	IBOutlet id Vc_FilterEGDepthBar;
	IBOutlet id Vc_FilterEGDepthEdit;
	IBOutlet id Vc_FilterEGAtkTVelSnsBar;
	IBOutlet id Vc_FilterEGAtkTVelSnsEdit;
	IBOutlet id Vc_FilterEGDepthVelSnsBar;
	IBOutlet id Vc_FilterEGDepthVelSnsEdit;
	IBOutlet id Vc_FilterEGTabSheet;

	IBOutlet id Vc_PitchGraphView;
	IBOutlet id Vc_PitchEGLv0Bar;
	IBOutlet id Vc_PitchEGLv0Edit;
	IBOutlet id Vc_PitchEGLv1Bar;
	IBOutlet id Vc_PitchEGLv1Edit;
	IBOutlet id Vc_PitchEGLv2Bar;
	IBOutlet id Vc_PitchEGLv2Edit;
	IBOutlet id Vc_PitchEGLv3Bar;
	IBOutlet id Vc_PitchEGLv3Edit;
	IBOutlet id Vc_PitchEGLv4Bar;
	IBOutlet id Vc_PitchEGLv4Edit;
	IBOutlet id Vc_PitchEGTime1Bar;
	IBOutlet id Vc_PitchEGTime1Edit;
	IBOutlet id Vc_PitchEGTime2Bar;
	IBOutlet id Vc_PitchEGTime2Edit;
	IBOutlet id Vc_PitchEGTime3Bar;
	IBOutlet id Vc_PitchEGTime3Edit;
	IBOutlet id Vc_PitchEGTime4Bar;
	IBOutlet id Vc_PitchEGTime4Edit;
	IBOutlet id Vc_PitchEGTimeScalingBar;
	IBOutlet id Vc_PitchEGTimeScalingEdit;
	IBOutlet id Vc_PitchEGRange;
	IBOutlet id Vc_PitchEGVelocitySensBar;
	IBOutlet id Vc_PitchEGVelocitySensEdit;
	IBOutlet id Vc_PitchEGTabSheet;

	IBOutlet id Vc_Frmt1Operator;
	IBOutlet id Vc_Frmt1Parameter;
	IBOutlet id Vc_Frmt1CtlDepthBar;
	IBOutlet id Vc_Frmt1CtlDepthEdit;
	IBOutlet id Vc_Frmt2Operator;
	IBOutlet id Vc_Frmt2Parameter;
	IBOutlet id Vc_Frmt2CtlDepthBar;
	IBOutlet id Vc_Frmt2CtlDepthEdit;
	IBOutlet id Vc_Frmt3Operator;
	IBOutlet id Vc_Frmt3Parameter;
	IBOutlet id Vc_Frmt3CtlDepthBar;
	IBOutlet id Vc_Frmt3CtlDepthEdit;
	IBOutlet id Vc_Frmt4Operator;
	IBOutlet id Vc_Frmt4Parameter;
	IBOutlet id Vc_Frmt4CtlDepthBar;
	IBOutlet id Vc_Frmt4CtlDepthEdit;
	IBOutlet id Vc_Frmt5Operator;
	IBOutlet id Vc_Frmt5Parameter;
	IBOutlet id Vc_Frmt5CtlDepthBar;
	IBOutlet id Vc_Frmt5CtlDepthEdit;

	IBOutlet id Vc_Fm1Operator;
	IBOutlet id Vc_Fm1Parameter;
	IBOutlet id Vc_Fm1CtlDepthBar;
	IBOutlet id Vc_Fm1CtlDepthEdit;
	IBOutlet id Vc_Fm2Operator;
	IBOutlet id Vc_Fm2Parameter;
	IBOutlet id Vc_Fm2CtlDepthBar;
	IBOutlet id Vc_Fm2CtlDepthEdit;
	IBOutlet id Vc_Fm3Operator;
	IBOutlet id Vc_Fm3Parameter;
	IBOutlet id Vc_Fm3CtlDepthBar;
	IBOutlet id Vc_Fm3CtlDepthEdit;
	IBOutlet id Vc_Fm4Operator;
	IBOutlet id Vc_Fm4Parameter;
	IBOutlet id Vc_Fm4CtlDepthBar;
	IBOutlet id Vc_Fm4CtlDepthEdit;
	IBOutlet id Vc_Fm5Operator;
	IBOutlet id Vc_Fm5Parameter;
	IBOutlet id Vc_Fm5CtlDepthBar;
	IBOutlet id Vc_Fm5CtlDepthEdit;

	IBOutlet id Vc_AlgorithmEdit;
	IBOutlet id Vc_Algorithm;
	IBOutlet id Vc_AlgorithmBtn;
	IBOutlet id Vc_FeedbackBar;
	IBOutlet id Vc_FeedbackEdit;
	IBOutlet id Vc_NoteShiftBar;
	IBOutlet id Vc_NoteShiftEdit;
	IBOutlet id Vc_GetDataBtn;
	IBOutlet id Vc_SendDataBtn;

	IBOutlet id Vc_AlgorithmView;

	IBOutlet id Vc_OpMute_VAll;
	IBOutlet id Vc_OpMute_VOp1;
	IBOutlet id Vc_OpMute_VOp2;
	IBOutlet id Vc_OpMute_VOp3;
	IBOutlet id Vc_OpMute_VOp4;
	IBOutlet id Vc_OpMute_VOp5;
	IBOutlet id Vc_OpMute_VOp6;
	IBOutlet id Vc_OpMute_VOp7;
	IBOutlet id Vc_OpMute_VOp8;
	IBOutlet id Vc_OpMute_UAll;
	IBOutlet id Vc_OpMute_UOp1;
	IBOutlet id Vc_OpMute_UOp2;
	IBOutlet id Vc_OpMute_UOp3;
	IBOutlet id Vc_OpMute_UOp4;
	IBOutlet id Vc_OpMute_UOp5;
	IBOutlet id Vc_OpMute_UOp6;
	IBOutlet id Vc_OpMute_UOp7;
	IBOutlet id Vc_OpMute_UOp8;

	IBOutlet id Vc_Operator;

	IBOutlet id Vc_VOpOSC;
	IBOutlet id Vc_VOpFseqSw;
	IBOutlet id Vc_VOpFseqSwText;
	IBOutlet id Vc_VOpFseqTrkBar;
	IBOutlet id Vc_VOpFseqTrkEdit;
	IBOutlet id Vc_VOpFseqTrkText;
	IBOutlet id Vc_VOpForm;
	IBOutlet id Vc_VOpFreqMode;
	IBOutlet id Vc_VOpFreqModeText;
	IBOutlet id Vc_VOpFreqCoarseBar;
	IBOutlet id Vc_VOpFreqFineBar;
	IBOutlet id Vc_VOpFreqEdit;
	IBOutlet id Vc_VOpFreqScalingBar;
	IBOutlet id Vc_VOpFreqScalingEdit;
	IBOutlet id Vc_VOpFreqScalingText;
	IBOutlet id Vc_VOpTransposeBar;
	IBOutlet id Vc_VOpTransposeEdit;
	IBOutlet id Vc_VOpTransposeText;
	IBOutlet id Vc_VOpDetuneBar;
	IBOutlet id Vc_VOpDetuneEdit;
	IBOutlet id Vc_VOpBandWidthBar;
	IBOutlet id Vc_VOpBandWidthEdit;
	IBOutlet id Vc_VOpBandWidthText;
	IBOutlet id Vc_VOpResonanceBar;
	IBOutlet id Vc_VOpResonanceEdit;
	IBOutlet id Vc_VOpResonanceText;
	IBOutlet id Vc_VOpSkirtBar;
	IBOutlet id Vc_VOpSkirtEdit;
	IBOutlet id Vc_VOpSkirtText;
	IBOutlet id Vc_VOpOutputLvlBar;
	IBOutlet id Vc_VOpOutputLvlEdit;
	IBOutlet id Vc_VOpOutputLvlText;
	IBOutlet id Vc_VOpKeySync;
	IBOutlet id Vc_VOpKeySyncText;
	IBOutlet id Vc_VOpLSBP;
	IBOutlet id Vc_VOpLSLeftDepthBar;
	IBOutlet id Vc_VOpLSLeftDepthEdit;
	IBOutlet id Vc_VOpLSLeftCrv;
	IBOutlet id Vc_VOpLSRightDepthBar;
	IBOutlet id Vc_VOpLSRightDepthEdit;
	IBOutlet id Vc_VOpLSRightCrv;
	IBOutlet id Vc_VOpOPAttBar;
	IBOutlet id Vc_VOpOPAttEdit;
	IBOutlet id Vc_VOpOPAttText;
	IBOutlet id Vc_VOpOPAttText2;

	IBOutlet id Vc_OpPresetEG;
	IBOutlet id Vc_OpEGShapeOpen;
	IBOutlet id Vc_OpEGShapeWrite;
	IBOutlet id Vc_OpEGShapeSave;
	IBOutlet id Vc_OpEGShapeDel;

	IBOutlet id Vc_OpEGGraphView;
	IBOutlet id Vc_OpEGHoldBar;
	IBOutlet id Vc_OpEGHoldEdit;
	IBOutlet id Vc_OpEGTime1Bar;
	IBOutlet id Vc_OpEGTime1Edit;
	IBOutlet id Vc_OpEGLv1Bar;
	IBOutlet id Vc_OpEGLv1Edit;
	IBOutlet id Vc_OpEGTime2Bar;
	IBOutlet id Vc_OpEGTime2Edit;
	IBOutlet id Vc_OpEGLv2Bar;
	IBOutlet id Vc_OpEGLv2Edit;
	IBOutlet id Vc_OpEGTime3Bar;
	IBOutlet id Vc_OpEGTime3Edit;
	IBOutlet id Vc_OpEGLv3Bar;
	IBOutlet id Vc_OpEGLv3Edit;
	IBOutlet id Vc_OpEGTime4Bar;
	IBOutlet id Vc_OpEGTime4Edit;
	IBOutlet id Vc_OpEGLv4Bar;
	IBOutlet id Vc_OpEGLv4Edit;
	IBOutlet id Vc_OpEGTimeScalingBar;
	IBOutlet id Vc_OpEGTimeScalingEdit;

	IBOutlet id Vc_OpFrqEGGraphView;
	IBOutlet id Vc_OpFrqEGInitLvlBar;
	IBOutlet id Vc_OpFrqEGInitLvlEdit;
	IBOutlet id Vc_OpFrqEGInitLvlText;
	IBOutlet id Vc_OpFrqEGAtakLvlBar;
	IBOutlet id Vc_OpFrqEGAtakLvlEdit;
	IBOutlet id Vc_OpFrqEGAtakLvlText;
	IBOutlet id Vc_OpFrqEGAtakTimeBar;
	IBOutlet id Vc_OpFrqEGAtakTimeEdit;
	IBOutlet id Vc_OpFrqEGAtakTimeText;
	IBOutlet id Vc_OpFrqEGDecayTimeBar;
	IBOutlet id Vc_OpFrqEGDecayTimeEdit;
	IBOutlet id Vc_OpFrqEGDecayTimeText;
	IBOutlet id Vc_OpSnsAmpVelBar;
	IBOutlet id Vc_OpSnsAmpVelEdit;
	IBOutlet id Vc_OpSnsFreqVelBar;
	IBOutlet id Vc_OpSnsFreqVelEdit;
	IBOutlet id Vc_OpSnsFreqVelText;
	IBOutlet id Vc_OpSnsAmpEGBiasBar;
	IBOutlet id Vc_OpSnsAmpEGBiasEdit;
	IBOutlet id Vc_OpSnsFreqBiasBar;
	IBOutlet id Vc_OpSnsFreqBiasEdit;
	IBOutlet id Vc_OpSnsFreqBiasText;
	IBOutlet id Vc_OpSnsWidthBiasBar;
	IBOutlet id Vc_OpSnsWidthBiasEdit;
	IBOutlet id Vc_OpSnsWidthBiasText;
	IBOutlet id Vc_OpPitchModBar;
	IBOutlet id Vc_OpPitchModEdit;
	IBOutlet id Vc_OpPitchModText;
	IBOutlet id Vc_OpAmpModBar;
	IBOutlet id Vc_OpAmpModEdit;
	IBOutlet id Vc_OpFreqModBar;
	IBOutlet id Vc_OpFreqModEdit;
	IBOutlet id Vc_OpFreqModText;

	IBOutlet id Vc_UOpOSC;
	IBOutlet id Vc_UOpFseqSw;
	IBOutlet id Vc_UOpFseqSwText;
	IBOutlet id Vc_UOpFseqTrkText;
	IBOutlet id Vc_UOpFreqMode;
	IBOutlet id Vc_UOpFreqModeLinkFF;
	IBOutlet id Vc_UOpFreqCoarseBar;
	IBOutlet id Vc_UOpFreqCoarseText;
	IBOutlet id Vc_UOpFreqFineBar;
	IBOutlet id Vc_UOpFreqFineText;
	IBOutlet id Vc_UOpFreqEdit;
	IBOutlet id Vc_UOpFreqEditText;
	IBOutlet id Vc_UOpFreqScalingBar;
	IBOutlet id Vc_UOpFreqScalingEdit;
	IBOutlet id Vc_UOpFreqScalingText;
	IBOutlet id Vc_UOpTransposeBar;
	IBOutlet id Vc_UOpTransposeEdit;
	IBOutlet id Vc_UOpBandWidthBar;
	IBOutlet id Vc_UOpBandWidthEdit;
	IBOutlet id Vc_UOpResonanceBar;
	IBOutlet id Vc_UOpResonanceEdit;
	IBOutlet id Vc_UOpSkirtBar;
	IBOutlet id Vc_UOpSkirtEdit;
	IBOutlet id Vc_UOpOutputLvlBar;
	IBOutlet id Vc_UOpOutputLvlEdit;
	IBOutlet id Vc_UOpOutputLvlText;
	IBOutlet id Vc_UOpLvlScalingBar;
	IBOutlet id Vc_UOpLvlScalingEdit;

	// Object of Effect Parameters
	IBOutlet id Pfm_Effect_EditSelectSw;

    IBOutlet id Pfm_Effect_ImageDryLvl1;
    IBOutlet id Pfm_Effect_ImageRevSend1;
    IBOutlet id Pfm_Effect_ImageVarSend1;
    IBOutlet id Pfm_Effect_ImageDryLvl2;
    IBOutlet id Pfm_Effect_ImageRevSend2;
    IBOutlet id Pfm_Effect_ImageVarSend2;
    IBOutlet id Pfm_Effect_ImageDryLvl3;
    IBOutlet id Pfm_Effect_ImageRevSend3;
    IBOutlet id Pfm_Effect_ImageVarSend3;
    IBOutlet id Pfm_Effect_ImageDryLvl4;
    IBOutlet id Pfm_Effect_ImageRevSend4;
    IBOutlet id Pfm_Effect_ImageVarSend4;
    IBOutlet id Pfm_Effect_ImageRevRtn;
    IBOutlet id Pfm_Effect_ImageVarSendtoRev;
    IBOutlet id Pfm_Effect_ImageVarRtn;
    IBOutlet id Pfm_Effect_ImageInsDryLvl;
    IBOutlet id Pfm_Effect_ImageInsSendtoRev;
    IBOutlet id Pfm_Effect_ImageInsSendtoVar;

    IBOutlet id Pfm_Effect_ImageIndividual;
    IBOutlet id Pfm_Effect_ImageInsSw;

    IBOutlet id Pfm_Effect_PartParaGrp;
    IBOutlet id Pfm_Effect_P1InsSw;
    IBOutlet id Pfm_Effect_P1DryLvlText;
    IBOutlet id Pfm_Effect_P1DryLvlBar;
    IBOutlet id Pfm_Effect_P1DryLvlEdit;
    IBOutlet id Pfm_Effect_P1RevSendText;
    IBOutlet id Pfm_Effect_P1RevSendEdit;
    IBOutlet id Pfm_Effect_P1RevSendBar;
    IBOutlet id Pfm_Effect_P1VarSendText;
    IBOutlet id Pfm_Effect_P1VarSendBar;
    IBOutlet id Pfm_Effect_P1VarSendEdit;

    IBOutlet id Pfm_Effect_P2InsSw;
    IBOutlet id Pfm_Effect_P2DryLvlText;
    IBOutlet id Pfm_Effect_P2DryLvlBar;
    IBOutlet id Pfm_Effect_P2DryLvlEdit;
    IBOutlet id Pfm_Effect_P2RevSendText;
    IBOutlet id Pfm_Effect_P2RevSendBar;
    IBOutlet id Pfm_Effect_P2RevSendEdit;
    IBOutlet id Pfm_Effect_P2VarSendText;
    IBOutlet id Pfm_Effect_P2VarSendBar;
    IBOutlet id Pfm_Effect_P2VarSendEdit;

    IBOutlet id Pfm_Effect_P3InsSw;
    IBOutlet id Pfm_Effect_P3DryLvlText;
    IBOutlet id Pfm_Effect_P3DryLvlBar;
    IBOutlet id Pfm_Effect_P3DryLvlEdit;
    IBOutlet id Pfm_Effect_P3RevSendText;
    IBOutlet id Pfm_Effect_P3RevSendEdit;
    IBOutlet id Pfm_Effect_P3RevSendBar;
    IBOutlet id Pfm_Effect_P3VarSendText;
    IBOutlet id Pfm_Effect_P3VarSendBar;
    IBOutlet id Pfm_Effect_P3VarSendEdit;

    IBOutlet id Pfm_Effect_P4InsSw;
    IBOutlet id Pfm_Effect_P4DryLvlText;
    IBOutlet id Pfm_Effect_P4DryLvlBar;
    IBOutlet id Pfm_Effect_P4DryLvlEdit;
    IBOutlet id Pfm_Effect_P4RevSendText;
    IBOutlet id Pfm_Effect_P4RevSendEdit;
    IBOutlet id Pfm_Effect_P4RevSendBar;
    IBOutlet id Pfm_Effect_P4VarSendText;
    IBOutlet id Pfm_Effect_P4VarSendBar;
    IBOutlet id Pfm_Effect_P4VarSendEdit;

    IBOutlet id Pfm_Effect_IndividualOutput;

    IBOutlet id Pfm_Effect_ParaGrp;
    IBOutlet id Pfm_Effect_Type;
    IBOutlet id Pfm_Effect_Para1Text;
    IBOutlet id Pfm_Effect_Para2Text;
    IBOutlet id Pfm_Effect_Para3Text;
    IBOutlet id Pfm_Effect_Para4Text;
    IBOutlet id Pfm_Effect_Para5Text;
    IBOutlet id Pfm_Effect_Para6Text;
    IBOutlet id Pfm_Effect_Para7Text;
    IBOutlet id Pfm_Effect_Para8Text;
    IBOutlet id Pfm_Effect_Para9Text;
    IBOutlet id Pfm_Effect_Para10Text;
    IBOutlet id Pfm_Effect_Para11Text;
    IBOutlet id Pfm_Effect_Para12Text;
    IBOutlet id Pfm_Effect_Para13Text;
    IBOutlet id Pfm_Effect_Para14Text;
    IBOutlet id Pfm_Effect_Para15Text;
    IBOutlet id Pfm_Effect_Para16Text;
    IBOutlet id Pfm_Effect_Para17Text;
    IBOutlet id Pfm_Effect_Para18Text;
    IBOutlet id Pfm_Effect_Para1Bar;
    IBOutlet id Pfm_Effect_Para2Bar;
    IBOutlet id Pfm_Effect_Para3Bar;
    IBOutlet id Pfm_Effect_Para4Bar;
    IBOutlet id Pfm_Effect_Para5Bar;
    IBOutlet id Pfm_Effect_Para6Bar;
    IBOutlet id Pfm_Effect_Para7Bar;
    IBOutlet id Pfm_Effect_Para8Bar;
    IBOutlet id Pfm_Effect_Para9Bar;
    IBOutlet id Pfm_Effect_Para10Bar;
    IBOutlet id Pfm_Effect_Para11Bar;
    IBOutlet id Pfm_Effect_Para12Bar;
    IBOutlet id Pfm_Effect_Para13Bar;
    IBOutlet id Pfm_Effect_Para14Bar;
    IBOutlet id Pfm_Effect_Para15Bar;
    IBOutlet id Pfm_Effect_Para16Bar;
    IBOutlet id Pfm_Effect_Para17Bar;
    IBOutlet id Pfm_Effect_Para18Bar;
    IBOutlet id Pfm_Effect_Para1Edit;
    IBOutlet id Pfm_Effect_Para2Edit;
    IBOutlet id Pfm_Effect_Para3Edit;
    IBOutlet id Pfm_Effect_Para4Edit;
    IBOutlet id Pfm_Effect_Para5Edit;
    IBOutlet id Pfm_Effect_Para6Edit;
    IBOutlet id Pfm_Effect_Para7Edit;
    IBOutlet id Pfm_Effect_Para8Edit;
    IBOutlet id Pfm_Effect_Para9Edit;
    IBOutlet id Pfm_Effect_Para10Edit;
    IBOutlet id Pfm_Effect_Para11Edit;
    IBOutlet id Pfm_Effect_Para12Edit;
    IBOutlet id Pfm_Effect_Para13Edit;
    IBOutlet id Pfm_Effect_Para14Edit;
    IBOutlet id Pfm_Effect_Para15Edit;
    IBOutlet id Pfm_Effect_Para16Edit;
    IBOutlet id Pfm_Effect_Para17Edit;
    IBOutlet id Pfm_Effect_Para18Edit;

    IBOutlet id EQ_GraphImage;
    IBOutlet id Pfm_Effect_EQ_LowShape;
    IBOutlet id Pfm_Effect_EQ_LowFreqBar;
    IBOutlet id Pfm_Effect_EQ_LowFreqEdit;
    IBOutlet id Pfm_Effect_EQ_LowGainBar;
    IBOutlet id Pfm_Effect_EQ_LowGainEdit;
    IBOutlet id Pfm_Effect_EQ_LowQText;
    IBOutlet id Pfm_Effect_EQ_LowQBar;
    IBOutlet id Pfm_Effect_EQ_LowQEdit;

    IBOutlet id Pfm_Effect_EQ_MidFreqBar;
    IBOutlet id Pfm_Effect_EQ_MidFreqEdit;
    IBOutlet id Pfm_Effect_EQ_MidGainBar;
    IBOutlet id Pfm_Effect_EQ_MidGainEdit;
    IBOutlet id Pfm_Effect_EQ_MidQBar;
    IBOutlet id Pfm_Effect_EQ_MidQEdit;

    IBOutlet id Pfm_Effect_EQ_HighShape;
    IBOutlet id Pfm_Effect_EQ_HighFreqBar;
    IBOutlet id Pfm_Effect_EQ_HighFreqEdit;
    IBOutlet id Pfm_Effect_EQ_HighGainBar;
    IBOutlet id Pfm_Effect_EQ_HighGainEdit;
    IBOutlet id Pfm_Effect_EQ_HighQText;
    IBOutlet id Pfm_Effect_EQ_HighQBar;
    IBOutlet id Pfm_Effect_EQ_HighQEdit;

}
// Buttons of MIDI Setting Panel
- (IBAction)MIDIIntPanel_Ok:(id)sender;
- (IBAction)MIDIIntPanel_Cancel:(id)sender;

// Buttons of Algolithm Select Panel
- (IBAction)AlgSelectPanel_OkPush:(id)sender;
- (IBAction)AlgSelectPanel_CancelPush:(id)sender;
- (IBAction)AlgSelectPanel_AlgEditChange:(id)sender;

// StorePannel
- (IBAction)StoreButton:(id)sender;
- (IBAction)StoreCancel:(id)sender;
- (IBAction)StoreEditChange:(id)sender;
- (IBAction)StoreBarChange:(id)sender;

// AboutPannel
- (IBAction)AboutPanelOpen:(id)sender;
- (IBAction)AboutClosePush:(id)sender;
- (IBAction)AboutWebPush:(id)sender;
- (IBAction)AboutMailPush:(id)sender;

// FSEQ Init Panel
- (IBAction)FSEQInitPanel_OKPush:(id)sender;

// VirtualMIDIKeyboadPanel
- (IBAction)VMIDIKeyPanel_B0Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C1sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_D1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_D1sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_E1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F1sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_G1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_G1sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_A1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_A1sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_B1Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C2sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_D2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_D2sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_E2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F2sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_G2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_G2sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_A2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_A2sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_B2Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C3sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_D3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_D3sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_E3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F3sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_G3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_G3sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_A3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_A3sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_B3Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C4sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_D4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_D4sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_E4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F4sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_G4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_G4sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_A4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_A4sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_B4Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_C5sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_D5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_D5sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_E5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_F5sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_G5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_G5sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_A5Push:(id)sender;
- (IBAction)VMIDIKeyPanel_A5sPush:(id)sender;
- (IBAction)VMIDIKeyPanel_B5Push:(id)sender;

- (IBAction)VMIDIKeyPanel_ChChange:(id)sender;
- (IBAction)VMIDIKeyPanel_OctShiftChange:(id)sender;
- (IBAction)VMIDIKeyPanel_VelocityBarChange:(id)sender;
- (IBAction)VMIDIKeyPanel_VelocityEditChange:(id)sender;
- (IBAction)VMIDIKeyPanel_Ctrl1BarChange:(id)sender;
- (IBAction)VMIDIKeyPanel_Ctrl1EditChange:(id)sender;
- (IBAction)VMIDIKeyPanel_Ctrl2BarChange:(id)sender;
- (IBAction)VMIDIKeyPanel_Ctrl2EditChange:(id)sender;
- (IBAction)VMIDIKeyPanel_KeyRetriggerPush:(id)sender;
- (IBAction)VMIDIKeyPanel_AllResetPush:(id)sender;

// Main Menu
	// File
- (IBAction)FileNewItemClick:(id)sender;
- (IBAction)FileOpenItemClick:(id)sender;
- (IBAction)FileSaveItemClick:(id)sender;
- (IBAction)ExportSMFClick:(id)sender;
    // Edit
- (IBAction)UndoClick:(id)sender;
- (IBAction)CopyClick:(id)sender;
- (IBAction)PasteClick:(id)sender;
- (IBAction)OPCopyClick:(id)sender;
- (IBAction)OPPasteClick:(id)sender;
	// tools
- (IBAction)DataSendPfmClick:(id)sender;
- (IBAction)DataSendVc1Click:(id)sender;
- (IBAction)DataSendVc2Click:(id)sender;
- (IBAction)DataSendVc3Click:(id)sender;
- (IBAction)DataSendVc4Click:(id)sender;
- (IBAction)DataSendAllClick:(id)sender;
- (IBAction)DataSendSysClick:(id)sender;
- (IBAction)DataRcvPfmClick:(id)sender;
- (IBAction)DataRcvVc1Click:(id)sender;
- (IBAction)DataRcvVc2Click:(id)sender;
- (IBAction)DataRcvVc3Click:(id)sender;
- (IBAction)DataRcvVc4Click:(id)sender;
- (IBAction)DataRcvSysClick:(id)sender;
- (IBAction)DataRcvAllClick:(id)sender;
- (IBAction)StorePfmClick:(id)sender;
- (IBAction)StoreVc1Click:(id)sender;
- (IBAction)StoreVc2Click:(id)sender;
- (IBAction)StoreVc3Click:(id)sender;
- (IBAction)StoreVc4Click:(id)sender;
- (IBAction)InitAllClick:(id)sender;
- (IBAction)InitPfmClick:(id)sender;
- (IBAction)InitVc1Click:(id)sender;
- (IBAction)InitVc2Click:(id)sender;
- (IBAction)InitVc3Click:(id)sender;
- (IBAction)InitVc4Click:(id)sender;
- (IBAction)InitSysClick:(id)sender;
	// Options
- (IBAction)MIDI_configClick:(id)sender;	
- (IBAction)VirtualKeyClick:(id)sender;
- (IBAction)PanicCancelClick:(id)sender;

// Objects of Main Window
- (IBAction)Pfm_NameChange:(id)sender;
- (IBAction)Pfm_CategoryChange:(id)sender;
- (IBAction)Pfm_ChChange:(id)sender;
- (IBAction)Pfm_PartMuteBtn1Push:(id)sender;
- (IBAction)Pfm_PartMuteBtn2Push:(id)sender;
- (IBAction)Pfm_PartMuteBtn3Push:(id)sender;
- (IBAction)Pfm_PartMuteBtn4Push:(id)sender;
- (IBAction)Pfm_VolumeBarChange:(id)sender;
- (IBAction)Pfm_VolumeEditChange:(id)sender;
- (IBAction)Pfm_PanBarChange:(id)sender;
- (IBAction)Pfm_PanChange:(id)sender;
- (IBAction)Pfm_ReverbRtnBarChange:(id)sender;
- (IBAction)Pfm_ReverbRtnEditChange:(id)sender;
- (IBAction)Pfm_VariationRtnBarChange:(id)sender;
- (IBAction)Pfm_VariationRtnEditChange:(id)sender;
- (IBAction)Pfm_NoteshiftBarChange:(id)sender;
- (IBAction)Pfm_NoteshiftEditChange:(id)sender;
- (IBAction)Pfm_ReceiveBtnPush:(id)sender;
- (IBAction)Pfm_TransmitBtnPush:(id)sender;

// Object of Part Parameters
- (IBAction)Pfm_Part_SelectMatrixClick:(id)sender;

- (IBAction)Pfm_Part_BankNumChange:(id)sender;
- (IBAction)Pfm_Part_PrgNumChange:(id)sender;
- (IBAction)Pfm_Part_RcvChChange:(id)sender;
- (IBAction)Pfm_Part_RcvChMaxChange:(id)sender;
- (IBAction)Pfm_Part_VolumeBarChange:(id)sender;
- (IBAction)Pfm_Part_VolumeEditChange:(id)sender;
- (IBAction)Pfm_Part_InsEffectSwClick:(id)sender;
- (IBAction)Pfm_Part_DryLevelBarChange:(id)sender;
- (IBAction)Pfm_Part_DryLevelEditChange:(id)sender;
- (IBAction)Pfm_Part_ReverbSendBarChange:(id)sender;
- (IBAction)Pfm_Part_ReverbSendEditChange:(id)sender;
- (IBAction)Pfm_Part_VariationSendBarChange:(id)sender;
- (IBAction)Pfm_Part_VariationSendEditChange:(id)sender;

- (IBAction)Pfm_Part_FormantBarChange:(id)sender;
- (IBAction)Pfm_Part_FormantEditChange:(id)sender;
- (IBAction)Pfm_Part_FmBarChange:(id)sender;
- (IBAction)Pfm_Part_FmEditChange:(id)sender;
- (IBAction)Pfm_Part_VNBalanceBarChange:(id)sender;
- (IBAction)Pfm_Part_VNBalanceEditChange:(id)sender;
- (IBAction)Pfm_Part_LFO1SpeedBarChange:(id)sender;
- (IBAction)Pfm_Part_LFO1SpeedEditChange:(id)sender;
- (IBAction)Pfm_Part_LFO1PmodBarChange:(id)sender;
- (IBAction)Pfm_Part_LFO1PmodEditChange:(id)sender;
- (IBAction)Pfm_Part_LFO1DelayBarChange:(id)sender;
- (IBAction)Pfm_Part_LFO1DelayEditChange:(id)sender;
- (IBAction)Pfm_Part_FilterSwClick:(id)sender;
- (IBAction)Pfm_Part_FilterFreqBarChange:(id)sender;
- (IBAction)Pfm_Part_FilterFreqEditChange:(id)sender;
- (IBAction)Pfm_Part_FilterResoBarChange:(id)sender;
- (IBAction)Pfm_Part_FilterResoEditChange:(id)sender;
- (IBAction)Pfm_Part_FilterEGDepthBarChange:(id)sender;
- (IBAction)Pfm_Part_FilterEGDepthEditChange:(id)sender;
- (IBAction)Pfm_Part_LFO2SpeedBarChange:(id)sender;
- (IBAction)Pfm_Part_LFO2SpeedEditChange:(id)sender;
- (IBAction)Pfm_Part_LFO2FltModBarChange:(id)sender;
- (IBAction)Pfm_Part_LFO2FltModEditChange:(id)sender;

- (IBAction)Pfm_Part_EGAtkTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_EGAtkTimeEditChange:(id)sender;
- (IBAction)Pfm_Part_EGDecayTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_EGDecayTimeEditChange:(id)sender;
- (IBAction)Pfm_Part_EGReleaseTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_EGReleaseTimeEditChange:(id)sender;

- (IBAction)Pfm_Part_PEGInitLvlBarChange:(id)sender;
- (IBAction)Pfm_Part_PEGInitLvlEditChange:(id)sender;
- (IBAction)Pfm_Part_PEGAtkTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_PEGAtkTimeEditChange:(id)sender;
- (IBAction)Pfm_Part_PEGRelLvlBarChange:(id)sender;
- (IBAction)Pfm_Part_PEGRelLvlEditChange:(id)sender;
- (IBAction)Pfm_Part_PEGRelTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_PEGRelTimeEditChange:(id)sender;

- (IBAction)Pfm_Part_DetuneBarChange:(id)sender;
- (IBAction)Pfm_Part_DetuneEditChange:(id)sender;
- (IBAction)Pfm_Part_NoteShiftBarChange:(id)sender;
- (IBAction)Pfm_Part_NoteShiftEditChange:(id)sender;
- (IBAction)Pfm_Part_PBRangeBarChange:(id)sender;
- (IBAction)Pfm_Part_PBRangeEditChange:(id)sender;
- (IBAction)Pfm_Part_PBRangeLoBarChange:(id)sender;
- (IBAction)Pfm_Part_PBRangeLoEditChange:(id)sender;
- (IBAction)Pfm_Part_PortaSwClick:(id)sender;
- (IBAction)Pfm_Part_PortaModeClick:(id)sender;
- (IBAction)Pfm_Part_PortaTimeBarChange:(id)sender;
- (IBAction)Pfm_Part_PortaTimeEditChange:(id)sender;

- (IBAction)Pfm_Part_MonoPolyClick:(id)sender;
- (IBAction)Pfm_Part_MonoPriorityClick:(id)sender;
- (IBAction)Pfm_Part_SustainRcvSwClick:(id)sender;
- (IBAction)Pfm_Part_ReserveNoteBarChange:(id)sender;
- (IBAction)Pfm_Part_ReserveNoteEditChange:(id)sender;
- (IBAction)Pfm_Part_NoteLimitLowChange:(id)sender;
- (IBAction)Pfm_Part_NoteLimitHighChange:(id)sender;
- (IBAction)Pfm_Part_VelLimitLowBarChange:(id)sender;
- (IBAction)Pfm_Part_VelLimitLowEditChange:(id)sender;
- (IBAction)Pfm_Part_VelLimitHighBarChange:(id)sender;
- (IBAction)Pfm_Part_VelLimitHighEditChange:(id)sender;
- (IBAction)Pfm_Part_VelSensDepthBarChange:(id)sender;
- (IBAction)Pfm_Part_VelSensDepthEditChange:(id)sender;
- (IBAction)Pfm_Part_VelSensOffsetBarChange:(id)sender;
- (IBAction)Pfm_Part_VelSensOffsetEditChange:(id)sender;
- (IBAction)Pfm_Part_ExpLimitLoBarChange:(id)sender;
- (IBAction)Pfm_Part_ExpLimitLoEditChange:(id)sender;
- (IBAction)Pfm_Part_PanBarChange:(id)sender;
- (IBAction)Pfm_Part_PanChange:(id)sender;
- (IBAction)Pfm_Part_PanScaleBarChange:(id)sender;
- (IBAction)Pfm_Part_PanScaleEditChange:(id)sender;
- (IBAction)Pfm_Part_PanModBarChange:(id)sender;
- (IBAction)Pfm_Part_PanModEditChange:(id)sender;

// Object of FSEQ Parameters
- (IBAction)Pfm_Fseq_PartClick:(id)sender;
- (IBAction)Pfm_Fseq_FseqBankClick:(id)sender;
- (IBAction)Pfm_Fseq_FseqIntChange:(id)sender;
- (IBAction)Pfm_Fseq_FseqIntWriteClick:(id)sender;
- (IBAction)Pfm_Fseq_FseqTestBtnClick:(id)sender;
- (IBAction)Pfm_Fseq_FseqIntClearClick:(id)sender;
- (IBAction)Pfm_Fseq_FseqPreChange:(id)sender;
- (IBAction)Pfm_Fseq_ModeClick:(id)sender;
- (IBAction)Pfm_Fseq_KeyOnTrigClick:(id)sender;
- (IBAction)Pfm_Fseq_SpeedSelectClick:(id)sender;
- (IBAction)Pfm_Fseq_SpeedmidiClick:(id)sender;
- (IBAction)Pfm_Fseq_SpeedDownBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_SpeedDownBtn2Push:(id)sender;
- (IBAction)Pfm_Fseq_SpeedBarChange:(id)sender;
- (IBAction)Pfm_Fseq_SpeedUpBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_SpeedUpBtn2Push:(id)sender;
- (IBAction)Pfm_Fseq_SpeedVelBarChange:(id)sender;
- (IBAction)Pfm_Fseq_SpeedVelEditChange:(id)sender;
- (IBAction)Pfm_Fseq_LevelVelBarChange:(id)sender;
- (IBAction)Pfm_Fseq_LevelVelEditChange:(id)sender;
- (IBAction)Pfm_Fseq_PitchClick:(id)sender;
- (IBAction)Pfm_Fseq_LoopModeClick:(id)sender;
- (IBAction)Pfm_Fseq_StartDelayBarChange:(id)sender;
- (IBAction)Pfm_Fseq_StartDelayEditChange:(id)sender;
- (IBAction)Pfm_Fseq_StartOffsetBarChange:(id)sender;
- (IBAction)Pfm_Fseq_StartOffsetEditChange:(id)sender;
- (IBAction)Pfm_Fseq_StartOffsetUpBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_StartOffsetDownBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_LoopStartBarChange:(id)sender;
- (IBAction)Pfm_Fseq_LoopStartEditChange:(id)sender;
- (IBAction)Pfm_Fseq_LoopStartUpBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_LoopStartDownBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_LoopEndBarChange:(id)sender;
- (IBAction)Pfm_Fseq_LoopEndEditChange:(id)sender;
- (IBAction)Pfm_Fseq_LoopEndUpBtnPush:(id)sender;
- (IBAction)Pfm_Fseq_LoopEndDownBtnPush:(id)sender;

// Object of System Parameters
- (IBAction)Pfm_SystemMstrTuneBarChange:(id)sender;
- (IBAction)Pfm_SystemMstrTuneEditChange:(id)sender;
- (IBAction)Pfm_SystemMstrNoteBarChange:(id)sender;
- (IBAction)Pfm_SystemMstrNoteEditChange:(id)sender;
- (IBAction)Pfm_SystemVelCrvClick:(id)sender;
- (IBAction)Pfm_SystemDumpIntervalClick:(id)sender;
- (IBAction)Pfm_SystemRcvNoteClick:(id)sender;
- (IBAction)Pfm_SystemBCCurveClick:(id)sender;
- (IBAction)Pfm_SystemKNCtrlModeClick:(id)sender;
- (IBAction)Pfm_SystemRcvKNCtrlClick:(id)sender;
- (IBAction)Pfm_SystemTrnKNCtrlClick:(id)sender;
- (IBAction)Pfm_SystemRcvPgmChangeClick:(id)sender;
- (IBAction)Pfm_SystemRcvBankSelectClick:(id)sender;
- (IBAction)Pfm_SystemRcvPgmModeClick:(id)sender;
- (IBAction)Pfm_SystemDataRcvBtnClick:(id)sender;
- (IBAction)Pfm_SystemDataSendBtnClick:(id)sender;

// Object of Control Parameters
- (IBAction)Pfm_Ctrl_ChkVC1Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest1Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth1BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth1EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC1PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC2Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest2Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth2BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth2EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC2PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC3Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest3Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth3BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth3EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC3PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC4Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest4Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth4BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth4EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC4PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC5Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest5Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth5BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth5EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC5PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC6Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest6Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth6BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth6EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC6PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC7Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest7Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth7BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth7EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC7PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_ChkVC8Change:(id)sender;
- (IBAction)Pfm_Ctrl_Dest8Change:(id)sender;
- (IBAction)Pfm_Ctrl_Depth8BarChange:(id)sender;
- (IBAction)Pfm_Ctrl_Depth8EditChange:(id)sender;
- (IBAction)Pfm_Ctrl_ChkVC8PartChange:(id)sender;

- (IBAction)Pfm_Ctrl_AssignKN1Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignKN2Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignKN3Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignKN4Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignMC1Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignMC2Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignMC3Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignMC4Change:(id)sender;
- (IBAction)Pfm_Ctrl_AssignFCChange:(id)sender;
- (IBAction)Pfm_Ctrl_AssignBCChange:(id)sender;
- (IBAction)Pfm_Ctrl_AssignFrmChange:(id)sender;
- (IBAction)Pfm_Ctrl_AssignFMChange:(id)sender;
- (IBAction)Pfm_Ctrl_AssignDefaultBtnPush:(id)sender;

// Object of Voice Parameters
- (IBAction)Vc_VoiceChange:(id)sender;
- (IBAction)Vc_NameChange:(id)sender;
- (IBAction)Vc_CategoryChange:(id)sender;

- (IBAction)Vc_LFO1WaveformChange:(id)sender;
- (IBAction)Vc_LFO1KeySyncClick:(id)sender;
- (IBAction)Vc_LFO1SpeedBarChange:(id)sender;
- (IBAction)Vc_LFO1SpeedEditChange:(id)sender;
- (IBAction)Vc_LFO1DelayBarChange:(id)sender;
- (IBAction)Vc_LFO1DelayEditChange:(id)sender;
- (IBAction)Vc_LFO1PModDepthBarChange:(id)sender;
- (IBAction)Vc_LFO1PModDepthEditChange:(id)sender;
- (IBAction)Vc_LFO1AModDepthBarChange:(id)sender;
- (IBAction)Vc_LFO1AModDepthEditChange:(id)sender;
- (IBAction)Vc_LFO1FreqModDepthBarChange:(id)sender;
- (IBAction)Vc_LFO1FreqModDepthEditChange:(id)sender;
- (IBAction)Vc_LFO1FltModDepthBarChange:(id)sender;
- (IBAction)Vc_LFO1FltModDepthEditChange:(id)sender;
- (IBAction)Vc_LFO2WaveformChange:(id)sender;
- (IBAction)Vc_LFO2KeySyncClick:(id)sender;
- (IBAction)Vc_LFO2SpeedBarChange:(id)sender;
- (IBAction)Vc_LFO2SpeedEditChange:(id)sender;
- (IBAction)Vc_LFO2PhaseClick:(id)sender;
- (IBAction)Vc_LFO2FltModDepthBarChange:(id)sender;
- (IBAction)Vc_LFO2FltModDepthEditChange:(id)sender;

- (IBAction)Vc_FilterPartSwClick:(id)sender;
- (IBAction)Vc_FilterInputGainBarChange:(id)sender;
- (IBAction)Vc_FilterInputGainEditChange:(id)sender;
- (IBAction)Vc_FilterTypeChange:(id)sender;
- (IBAction)Vc_FilterCutoffFreqBarChange:(id)sender;
- (IBAction)Vc_FilterCutoffFreqEditChange:(id)sender;
- (IBAction)Vc_FilterResonanceBarChange:(id)sender;
- (IBAction)Vc_FilterResonanceEditChange:(id)sender;
- (IBAction)Vc_FilterFreqScalingBarChange:(id)sender;
- (IBAction)Vc_FilterFreqScalingEditChange:(id)sender;
- (IBAction)Vc_FilterFScaleBPChange:(id)sender;
- (IBAction)Vc_FilterResoVelSnsBarChange:(id)sender;
- (IBAction)Vc_FilterResoVelSnsEditChange:(id)sender;

- (IBAction)Vc_FilterEGTime1BarChange:(id)sender;
- (IBAction)Vc_FilterEGTime1EditChange:(id)sender;
- (IBAction)Vc_FilterEGTime2BarChange:(id)sender;
- (IBAction)Vc_FilterEGTime2EditChange:(id)sender;
- (IBAction)Vc_FilterEGTime3BarChange:(id)sender;
- (IBAction)Vc_FilterEGTime3EditChange:(id)sender;
- (IBAction)Vc_FilterEGTime4BarChange:(id)sender;
- (IBAction)Vc_FilterEGTime4EditChange:(id)sender;
- (IBAction)Vc_FilterEGLv1BarChange:(id)sender;
- (IBAction)Vc_FilterEGLv1EditChange:(id)sender;
- (IBAction)Vc_FilterEGLv2BarChange:(id)sender;
- (IBAction)Vc_FilterEGLv2EditChange:(id)sender;
- (IBAction)Vc_FilterEGLv3BarChange:(id)sender;
- (IBAction)Vc_FilterEGLv3EditChange:(id)sender;
- (IBAction)Vc_FilterEGLv4BarChange:(id)sender;
- (IBAction)Vc_FilterEGLv4EditChange:(id)sender;
- (IBAction)Vc_FilterEGTimeScalingBarChange:(id)sender;
- (IBAction)Vc_FilterEGTimeScalingEditChange:(id)sender;
- (IBAction)Vc_FilterEGDepthBarChange:(id)sender;
- (IBAction)Vc_FilterEGDepthEditChange:(id)sender;
- (IBAction)Vc_FilterEGAtkTVelSnsBarChange:(id)sender;
- (IBAction)Vc_FilterEGAtkTVelSnsEditChange:(id)sender;
- (IBAction)Vc_FilterEGDepthVelSnsBarChange:(id)sender;
- (IBAction)Vc_FilterEGDepthVelSnsEditChange:(id)sender;

- (IBAction)Vc_PitchEGLv0BarChange:(id)sender;
- (IBAction)Vc_PitchEGLv0EditChange:(id)sender;
- (IBAction)Vc_PitchEGLv1BarChange:(id)sender;
- (IBAction)Vc_PitchEGLv1EditChange:(id)sender;
- (IBAction)Vc_PitchEGLv2BarChange:(id)sender;
- (IBAction)Vc_PitchEGLv2EditChange:(id)sender;
- (IBAction)Vc_PitchEGLv3BarChange:(id)sender;
- (IBAction)Vc_PitchEGLv3EditChange:(id)sender;
- (IBAction)Vc_PitchEGLv4BarChange:(id)sender;
- (IBAction)Vc_PitchEGLv4EditChange:(id)sender;
- (IBAction)Vc_PitchEGTime1BarChange:(id)sender;
- (IBAction)Vc_PitchEGTime1EditChange:(id)sender;
- (IBAction)Vc_PitchEGTime2BarChange:(id)sender;
- (IBAction)Vc_PitchEGTime2EditChange:(id)sender;
- (IBAction)Vc_PitchEGTime3BarChange:(id)sender;
- (IBAction)Vc_PitchEGTime3EditChange:(id)sender;
- (IBAction)Vc_PitchEGTime4BarChange:(id)sender;
- (IBAction)Vc_PitchEGTime4EditChange:(id)sender;
- (IBAction)Vc_PitchEGTimeScalingBarChange:(id)sender;
- (IBAction)Vc_PitchEGTimeScalingEditChange:(id)sender;
- (IBAction)Vc_PitchEGRangeClick:(id)sender;
- (IBAction)Vc_PitchEGVelocitySensBarChange:(id)sender;
- (IBAction)Vc_PitchEGVelocitySensEditChange:(id)sender;

- (IBAction)Vc_Frmt1OperatorChange:(id)sender;
- (IBAction)Vc_Frmt1CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Frmt1CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Frmt2OperatorChange:(id)sender;
- (IBAction)Vc_Frmt2CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Frmt2CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Frmt3OperatorChange:(id)sender;
- (IBAction)Vc_Frmt3CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Frmt3CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Frmt4OperatorChange:(id)sender;
- (IBAction)Vc_Frmt4CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Frmt4CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Frmt5OperatorChange:(id)sender;
- (IBAction)Vc_Frmt5CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Frmt5CtlDepthEditChange:(id)sender;

- (IBAction)Vc_Fm1OperatorChange:(id)sender;
- (IBAction)Vc_Fm1CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Fm1CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Fm2OperatorChange:(id)sender;
- (IBAction)Vc_Fm2CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Fm2CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Fm3OperatorChange:(id)sender;
- (IBAction)Vc_Fm3CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Fm3CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Fm4OperatorChange:(id)sender;
- (IBAction)Vc_Fm4CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Fm4CtlDepthEditChange:(id)sender;
- (IBAction)Vc_Fm5OperatorChange:(id)sender;
- (IBAction)Vc_Fm5CtlDepthBarChange:(id)sender;
- (IBAction)Vc_Fm5CtlDepthEditChange:(id)sender;

- (IBAction)Vc_AlgorithmEditChange:(id)sender;
- (IBAction)Vc_AlgorithmChange:(id)sender;
- (IBAction)Vc_AlgorithmBtnPush:(id)sender;
- (IBAction)Vc_FeedbackBarChange:(id)sender;
- (IBAction)Vc_FeedbackEditChange:(id)sender;
- (IBAction)Vc_NoteShiftBarChange:(id)sender;
- (IBAction)Vc_NoteShiftEditChange:(id)sender;
- (IBAction)Vc_GetDataBtnPush:(id)sender;
- (IBAction)Vc_SendDataBtnPush:(id)sender;

- (IBAction)Vc_OpMute_VAllPush:(id)sender;
- (IBAction)Vc_OpMute_VOp1Push:(id)sender;
- (IBAction)Vc_OpMute_VOp2Push:(id)sender;
- (IBAction)Vc_OpMute_VOp3Push:(id)sender;
- (IBAction)Vc_OpMute_VOp4Push:(id)sender;
- (IBAction)Vc_OpMute_VOp5Push:(id)sender;
- (IBAction)Vc_OpMute_VOp6Push:(id)sender;
- (IBAction)Vc_OpMute_VOp7Push:(id)sender;
- (IBAction)Vc_OpMute_VOp8Push:(id)sender;
- (IBAction)Vc_OpMute_UAllPush:(id)sender;
- (IBAction)Vc_OpMute_UOp1Push:(id)sender;
- (IBAction)Vc_OpMute_UOp2Push:(id)sender;
- (IBAction)Vc_OpMute_UOp3Push:(id)sender;
- (IBAction)Vc_OpMute_UOp4Push:(id)sender;
- (IBAction)Vc_OpMute_UOp5Push:(id)sender;
- (IBAction)Vc_OpMute_UOp6Push:(id)sender;
- (IBAction)Vc_OpMute_UOp7Push:(id)sender;
- (IBAction)Vc_OpMute_UOp8Push:(id)sender;

- (IBAction)Vc_OperatorChange:(id)sender;

- (IBAction)Vc_VOpFseqSwClick:(id)sender;
- (IBAction)Vc_VOpFseqTrkBarChange:(id)sender;
- (IBAction)Vc_VOpFseqTrkEditChange:(id)sender;
- (IBAction)Vc_VOpFormChange:(id)sender;
- (IBAction)Vc_VOpFreqModeClick:(id)sender;
- (IBAction)Vc_VOpFreqCoarseBarChange:(id)sender;
- (IBAction)Vc_VOpFreqFineBarChange:(id)sender;
- (IBAction)Vc_VOpFreqScalingBarChange:(id)sender;
- (IBAction)Vc_VOpFreqScalingEditChange:(id)sender;
- (IBAction)Vc_VOpTransposeBarChange:(id)sender;
- (IBAction)Vc_VOpTransposeEditChange:(id)sender;
- (IBAction)Vc_VOpDetuneBarChange:(id)sender;
- (IBAction)Vc_VOpDetuneEditChange:(id)sender;
- (IBAction)Vc_VOpBandWidthBarChange:(id)sender;
- (IBAction)Vc_VOpBandWidthEditChange:(id)sender;
- (IBAction)Vc_VOpResonanceBarChange:(id)sender;
- (IBAction)Vc_VOpResonanceEditChange:(id)sender;
- (IBAction)Vc_VOpSkirtBarChange:(id)sender;
- (IBAction)Vc_VOpSkirtEditChange:(id)sender;
- (IBAction)Vc_VOpOutputLvlBarChange:(id)sender;
- (IBAction)Vc_VOpOutputLvlEditChange:(id)sender;
- (IBAction)Vc_VOpKeySyncClick:(id)sender;
- (IBAction)Vc_VOpLSBPChange:(id)sender;
- (IBAction)Vc_VOpLSLeftDepthBarChange:(id)sender;
- (IBAction)Vc_VOpLSLeftDepthEditChange:(id)sender;
- (IBAction)Vc_VOpLSLeftCrvClick:(id)sender;
- (IBAction)Vc_VOpLSRightDepthBarChange:(id)sender;
- (IBAction)Vc_VOpLSRightDepthEditChange:(id)sender;
- (IBAction)Vc_VOpLSRightCrvClick:(id)sender;
- (IBAction)Vc_VOpOPAttBarChange:(id)sender;

- (IBAction)Vc_OpPresetEGChange:(id)sender;
- (IBAction)Vc_OpEGShapeOpenPush:(id)sender;
- (IBAction)Vc_OpEGShapeWritePush:(id)sender;
- (IBAction)Vc_OpEGShapeSavePush:(id)sender;
- (IBAction)Vc_OpEGShapeDelPush:(id)sender;

- (IBAction)Vc_OpEGHoldBarChange:(id)sender;
- (IBAction)Vc_OpEGHoldEditChange:(id)sender;
- (IBAction)Vc_OpEGTime1BarChange:(id)sender;
- (IBAction)Vc_OpEGTime1EditChange:(id)sender;
- (IBAction)Vc_OpEGLv1BarChange:(id)sender;
- (IBAction)Vc_OpEGLv1EditChange:(id)sender;
- (IBAction)Vc_OpEGTime2BarChange:(id)sender;
- (IBAction)Vc_OpEGTime2EditChange:(id)sender;
- (IBAction)Vc_OpEGLv2BarChange:(id)sender;
- (IBAction)Vc_OpEGLv2EditChange:(id)sender;
- (IBAction)Vc_OpEGTime3BarChange:(id)sender;
- (IBAction)Vc_OpEGTime3EditChange:(id)sender;
- (IBAction)Vc_OpEGLv3BarChange:(id)sender;
- (IBAction)Vc_OpEGLv3EditChange:(id)sender;
- (IBAction)Vc_OpEGTime4BarChange:(id)sender;
- (IBAction)Vc_OpEGTime4EditChange:(id)sender;
- (IBAction)Vc_OpEGLv4BarChange:(id)sender;
- (IBAction)Vc_OpEGLv4EditChange:(id)sender;
- (IBAction)Vc_OpEGTimeScalingBarChange:(id)sender;
- (IBAction)Vc_OpEGTimeScalingEditChange:(id)sender;
- (IBAction)Vc_OpFrqEGInitLvlBarChange:(id)sender;
- (IBAction)Vc_OpFrqEGInitLvlEditChange:(id)sender;
- (IBAction)Vc_OpFrqEGAtakLvlBarChange:(id)sender;
- (IBAction)Vc_OpFrqEGAtakLvlEditChange:(id)sender;
- (IBAction)Vc_OpFrqEGAtakTimeBarChange:(id)sender;
- (IBAction)Vc_OpFrqEGAtakTimeEditChange:(id)sender;
- (IBAction)Vc_OpFrqEGDecayTimeBarChange:(id)sender;
- (IBAction)Vc_OpFrqEGDecayTimeEditChange:(id)sender;
- (IBAction)Vc_OpSnsAmpVelBarChange:(id)sender;
- (IBAction)Vc_OpSnsAmpVelEditChange:(id)sender;
- (IBAction)Vc_OpSnsFreqVelBarChange:(id)sender;
- (IBAction)Vc_OpSnsFreqVelEditChange:(id)sender;
- (IBAction)Vc_OpSnsAmpEGBiasBarChange:(id)sender;
- (IBAction)Vc_OpSnsAmpEGBiasEditChange:(id)sender;
- (IBAction)Vc_OpSnsFreqBiasBarChange:(id)sender;
- (IBAction)Vc_OpSnsFreqBiasEditChange:(id)sender;
- (IBAction)Vc_OpSnsWidthBiasBarChange:(id)sender;
- (IBAction)Vc_OpSnsWidthBiasEditChange:(id)sender;
- (IBAction)Vc_OpPitchModBarChange:(id)sender;
- (IBAction)Vc_OpPitchModEditChange:(id)sender;
- (IBAction)Vc_OpAmpModBarChange:(id)sender;
- (IBAction)Vc_OpAmpModEditChange:(id)sender;
- (IBAction)Vc_OpFreqModBarChange:(id)sender;
- (IBAction)Vc_OpFreqModEditChange:(id)sender;
- (IBAction)Vc_UOpFseqSwClick:(id)sender;
- (IBAction)Vc_UOpFreqModeClick:(id)sender;
- (IBAction)Vc_UOpFreqCoarseBarChange:(id)sender;
- (IBAction)Vc_UOpFreqFineBarChange:(id)sender;
- (IBAction)Vc_UOpFreqScalingBarChange:(id)sender;
- (IBAction)Vc_UOpFreqScalingEditChange:(id)sender;
- (IBAction)Vc_UOpTransposeBarChange:(id)sender;
- (IBAction)Vc_UOpTransposeEditChange:(id)sender;
- (IBAction)Vc_UOpBandWidthBarChange:(id)sender;
- (IBAction)Vc_UOpBandWidthEditChange:(id)sender;
- (IBAction)Vc_UOpResonanceBarChange:(id)sender;
- (IBAction)Vc_UOpResonanceEditChange:(id)sender;
- (IBAction)Vc_UOpSkirtBarChange:(id)sender;
- (IBAction)Vc_UOpSkirtEditChange:(id)sender;
- (IBAction)Vc_UOpOutputLvlBarChange:(id)sender;
- (IBAction)Vc_UOpOutputLvlEditChange:(id)sender;
- (IBAction)Vc_UOpLvlScalingBarChange:(id)sender;
- (IBAction)Vc_UOpLvlScalingEditChange:(id)sender;

// Object of Effect Parameters
- (IBAction)Pfm_Effect_EditSelectSwChange:(id)sender;

- (IBAction)Pfm_Effect_P1InsSwChange:(id)sender;
- (IBAction)Pfm_Effect_P1DryLvlBarChange:(id)sender;
- (IBAction)Pfm_Effect_P1DryLvlEditChange:(id)sender;
- (IBAction)Pfm_Effect_P1RevSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P1RevSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P1VarSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P1VarSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P2InsSwChange:(id)sender;
- (IBAction)Pfm_Effect_P2DryLvlBarChange:(id)sender;
- (IBAction)Pfm_Effect_P2DryLvlEditChange:(id)sender;
- (IBAction)Pfm_Effect_P2RevSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P2RevSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P2VarSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P2VarSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P3InsSwChange:(id)sender;
- (IBAction)Pfm_Effect_P3DryLvlBarChange:(id)sender;
- (IBAction)Pfm_Effect_P3DryLvlEditChange:(id)sender;
- (IBAction)Pfm_Effect_P3RevSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P3RevSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P3VarSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P3VarSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P4InsSwChange:(id)sender;
- (IBAction)Pfm_Effect_P4DryLvlBarChange:(id)sender;
- (IBAction)Pfm_Effect_P4DryLvlEditChange:(id)sender;
- (IBAction)Pfm_Effect_P4RevSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P4RevSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_P4VarSendBarChange:(id)sender;
- (IBAction)Pfm_Effect_P4VarSendEditChange:(id)sender;
- (IBAction)Pfm_Effect_IndividualOutputChange:(id)sender;

- (IBAction)Pfm_Effect_TypeChange:(id)sender;
- (IBAction)Pfm_Effect_Para1BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para2BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para3BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para4BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para5BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para6BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para7BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para8BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para9BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para10BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para11BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para12BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para13BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para14BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para15BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para16BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para17BarChange:(id)sender;
- (IBAction)Pfm_Effect_Para18BarChange:(id)sender;

- (IBAction)Pfm_Effect_EQ_LowShapeChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_LowFreqBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_LowGainBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_LowQBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_MidFreqBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_MidGainBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_MidQBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_HighShapeChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_HighFreqBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_HighGainBarChange:(id)sender;
- (IBAction)Pfm_Effect_EQ_HighQBarChange:(id)sender;

//------------------------------------------
- (void)awakeFromNib;
- (void)applicationDidFinishLaunching:(NSNotification *)aNotification;
- (void)applicationWillTerminate:(NSNotification *)aNotification;
- (BOOL)applicationShouldTerminate:(NSApplication *)theApplication;
- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)theApplication;


- (void)tabView:(NSTabView *)tabView didSelectTabViewItem:(NSTabViewItem *)tabViewItem;

// MIDI Functions
static void	FS1REditorReadProc(const MIDIPacketList *Pktlist, void *RefCon, void *ConnRefCon);
static void	MIDIKeyboardReadProc(const MIDIPacketList *Pktlist, void *RefCon, void *ConnRefCon);
void SendShortSysEx(Byte ShortSysEx[], int Size);
void SendLongSysEx(Byte LongSysEx[], int Size);
void NoteOn(Byte channel, Byte note, Byte velocity);
void NoteOff(Byte channel, Byte note, Byte velocity);
void CtrlChange(Byte channel, Byte Ctrl, Byte Value);

// Common Functions
- (void)TableCreate;

// Initialize Function
- (void)Init_All_Para;
- (void)Init_Pfm_Para;
- (void)Pfm_Common_ParaInit;
- (void)Pfm_Part_ParaInit:(int)Part;
- (void)Pfm_FSEQ_ParaInit;
- (void)System_ParaInit;
- (void)Effect_ParaInit;
- (void)Vc_All_ParaInit;
- (void)Vc_ParaInit:(int)Vc;
- (void)Vc_Common_ParaInit:(int)Vc;
- (void)Vc_VOpOsc_ParaInit:(int)Vc andOp:(int)Op;
- (void)Vc_UOpOsc_ParaInit:(int)Vc andOp:(int)Op;

// Set data to Contorol objects
- (void)Pfm_ParaSet;
- (void)Pfm_Common_ParaSet;
- (void)Pfm_Part_ParaSet:(int)Part;
- (void)Pfm_FSEQ_ParaSet;
- (void)Control_ParaSet;
- (void)Effect_ParaSet;
- (void)EQ_ParaSet;
- (void)Vc_ParaSet:(int)Vc;
- (void)Vc_Common_ParaSet:(int)Vc;
- (void)Vc_VOp_ParaSet:(int)Vc andOp:(int)Op;
- (void)Vc_UOp_ParaSet:(int)Vc andOp:(int)Op;

// Check routine
- (void)Pfm_FilterSwCheck;
- (void)Pfm_NoteReserveCheck;
- (void)UpdateCheck;
- (void)PartMuteCheck;
- (void)VoiceMuteCheck:(int)Vc;

// Exclusive
- (void)MidiInDataSet;
- (void)DataSend:(int)Type andStoreNum:(int)StoreNum;
- (void)Sysex_Pfm_Create:(int)Type andNum:(int)Num;
- (void)Sysex_Vc_Create:(int)Vc andNum:(int)Num;
- (void)Sysex_Sys_Create;

@end
